@@ -7,10 +7,9 @@
 (put 'cd-tool 'custom-loads '(cd-tool))
 (put 'dtk 'custom-loads '(dtk-speak))
 (put 'dtk-unicode 'custom-loads '(dtk-unicode))
-(put 'emacspeak 'custom-loads '(dtk-speak dtk-unicode emacspeak emacspeak-add-log emacspeak-advice emacspeak-alsaplayer emacspeak-aumix emacspeak-bookshare emacspeak-daisy emacspeak-dbus emacspeak-dismal emacspeak-epub emacspeak-erc emacspeak-eshell emacspeak-eterm emacspeak-eudc emacspeak-flyspell emacspeak-forms emacspeak-gnus emacspeak-ido emacspeak-ispell emacspeak-jss emacspeak-keymap emacspeak-kite emacspeak-librivox emacspeak-m-player emacspeak-message emacspeak-midge emacspeak-npr emacspeak-nxml emacspeak-ocr emacspeak-pronounce emacspeak-replace emacspeak-sounds emacspeak-speak emacspeak-speedbar emacspeak-table-ui emacspeak-vm emacspeak-w3 emacspeak-w3m emacspeak-we emacspeak-websearch emacspeak-webutils emacspeak-widget emacspeak-wizards emacspeak-xml-shell emacspeak-xslt voice-setup))
+(put 'emacspeak 'custom-loads '(dtk-speak dtk-unicode emacspeak emacspeak-add-log emacspeak-advice emacspeak-alsaplayer emacspeak-aumix emacspeak-bookshare emacspeak-daisy emacspeak-dbus emacspeak-dismal emacspeak-epub emacspeak-erc emacspeak-eshell emacspeak-eterm emacspeak-eudc emacspeak-feeds emacspeak-flyspell emacspeak-forms emacspeak-gnus emacspeak-ido emacspeak-ispell emacspeak-jss emacspeak-keymap emacspeak-kite emacspeak-librivox emacspeak-m-player emacspeak-message emacspeak-midge emacspeak-npr emacspeak-nxml emacspeak-ocr emacspeak-pronounce emacspeak-replace emacspeak-sounds emacspeak-speak emacspeak-speedbar emacspeak-table-ui emacspeak-vm emacspeak-w3 emacspeak-w3m emacspeak-we emacspeak-websearch emacspeak-widget emacspeak-wizards emacspeak-xml-shell emacspeak-xslt voice-setup))
 (put 'emacspeak-advice 'custom-loads '(emacspeak-advice))
 (put 'emacspeak-alsaplayer 'custom-loads '(emacspeak-alsaplayer))
-(put 'emacspeak-atom 'custom-loads '(emacspeak-webutils))
 (put 'emacspeak-aumix 'custom-loads '(emacspeak-aumix))
 (put 'emacspeak-bookshare 'custom-loads '(emacspeak-bookshare))
 (put 'emacspeak-calendar 'custom-loads '(emacspeak-calendar))
@@ -25,6 +24,8 @@
 (put 'emacspeak-eshell 'custom-loads '(emacspeak-eshell))
 (put 'emacspeak-eterm 'custom-loads '(emacspeak-eterm))
 (put 'emacspeak-eudc 'custom-loads '(emacspeak-eudc))
+(put 'emacspeak-eww 'custom-loads '(emacspeak-eww))
+(put 'emacspeak-feeds 'custom-loads '(emacspeak-feeds))
 (put 'emacspeak-forms 'custom-loads '(emacspeak-forms))
 (put 'emacspeak-gnus 'custom-loads '(emacspeak-gnus))
 (put 'emacspeak-hide 'custom-loads '(emacspeak-hide))
@@ -44,7 +45,6 @@
 (put 'emacspeak-personality 'custom-loads '(emacspeak-personality))
 (put 'emacspeak-pronounce 'custom-loads '(emacspeak-pronounce))
 (put 'emacspeak-remote 'custom-loads '(emacspeak-remote))
-(put 'emacspeak-rss 'custom-loads '(emacspeak-webutils))
 (put 'emacspeak-sounds 'custom-loads '(emacspeak-sounds))
 (put 'emacspeak-speak 'custom-loads '(emacspeak-advice emacspeak-speak emacspeak-wizards))
 (put 'emacspeak-speedbar 'custom-loads '(emacspeak-speedbar))
@@ -56,11 +56,10 @@
 (put 'emacspeak-w3m 'custom-loads '(emacspeak-w3m))
 (put 'emacspeak-we 'custom-loads '(emacspeak-we))
 (put 'emacspeak-websearch 'custom-loads '(emacspeak-websearch))
-(put 'emacspeak-webspace 'custom-loads '(emacspeak-webspace))
 (put 'emacspeak-webutils 'custom-loads '(emacspeak-webutils))
 (put 'emacspeak-wizards 'custom-loads '(emacspeak-wizards))
 (put 'emacspeak-xml-shell 'custom-loads '(emacspeak-xml-shell))
-(put 'emacspeak-xsl 'custom-loads '(emacspeak-webutils))
+(put 'emacspeak-xsl 'custom-loads '(emacspeak-feeds))
 (put 'emacspeak-xslide 'custom-loads '(emacspeak-xslide))
 (put 'emacspeak-xslt 'custom-loads '(emacspeak-xslt))
 (put 'eshell 'custom-loads '(emacspeak-eshell))
@@ -71,7 +70,6 @@
 (put 'gnus 'custom-loads '(emacspeak-gnus))
 (put 'isearch 'custom-loads '(emacspeak-replace))
 (put 'message 'custom-loads '(emacspeak-message))
-(put 'nil 'custom-loads '(emacspeak-webspace))
 (put 'speedbar 'custom-loads '(emacspeak-speedbar))
 (put 'tetris 'custom-loads '(tetris))
 (put 'tts 'custom-loads '(dtk-speak emacspeak-setup))
