@@ -1,5 +1,5 @@
 ;;; emacspeak-ispell.el --- Speech enable Ispell -- Emacs' interactive spell checker
-;;; $Id: emacspeak-flyspell.el 5222 2007-08-26 01:28:19Z tv.raman.tv $
+;;; $Id: emacspeak-flyspell.el 8574 2013-11-24 02:01:07Z tv.raman.tv $
 ;;; $Author: tv.raman.tv $ 
 ;;; Description:  Emacspeak extension to speech enable flyspell
 ;;; Keywords: Emacspeak, Ispell, Spoken Output, fly spell checking
@@ -15,7 +15,7 @@
 
 ;;}}}
 ;;{{{  Copyright:
-;;;Copyright (C) 1995 -- 2007, T. V. Raman 
+;;;Copyright (C) 1995 -- 2011, T. V. Raman 
 ;;; Copyright (c) 1994, 1995 by Digital Equipment Corporation.
 ;;; All Rights Reserved. 
 ;;;
@@ -46,8 +46,10 @@
 
 ;;}}}
 ;;{{{ Requires
+(require 'cl)
+(declaim  (optimize  (safety 0) (speed 3)))
 (require 'emacspeak-preamble)
-
+(require 'flyspell)
 ;;}}}
 ;;{{{  define personalities
 
@@ -59,7 +61,7 @@
 
 (voice-setup-add-map
  '(
-   (flyspell-incorrect-face voice-bolden)
+   (flyspell-incorrect voice-bolden)
    ))
 
 ;;}}}
@@ -70,7 +72,7 @@
 (defadvice flyspell-auto-correct-word (around emacspeak pre act comp)
   "Speak the correction we inserted"
   (cond
-   ((interactive-p)
+   ((ems-interactive-p )
     ad-do-it
     (dtk-speak (car  (flyspell-get-word nil)))
     (emacspeak-auditory-icon 'select-object))
@@ -95,9 +97,9 @@
   "Put property personality with value
 `voice-animate' from beg to end"
   (declare (special voice-animate))
-  (ems-modify-buffer-safely
-   (put-text-property beg end 'personality
-                      voice-animate))
+  (with-silent-modifications
+    (put-text-property beg end 'personality
+                       voice-animate))
   (emacspeak-speak-region beg end)
   nil)
 
@@ -109,7 +111,7 @@
 
 ;;; local variables:
 ;;; folded-file: t
-;;; byte-compile-dynamic: t
+;;; byte-compile-dynamic: nil
 ;;; end: 
 
 ;;}}}
