@@ -1,5 +1,5 @@
 ;;; emacspeak-gnus.el --- Speech enable GNUS -- Fluent spoken access to usenet
-;;; $Id: emacspeak-gnus.el 8535 2013-11-13 01:49:39Z tv.raman.tv $
+;;; $Id: emacspeak-gnus.el 9072 2014-04-16 15:27:01Z tv.raman.tv $
 ;;; $Author: tv.raman.tv $ 
 ;;; Description:  Emacspeak extension to speech enable Gnus
 ;;; Keywords: Emacspeak, Gnus, Advice, Spoken Output, News
@@ -42,20 +42,17 @@
 ;;; Commentary
 
 ;;; This module advices gnus to speak. 
+;;; Updating support in 2014 (Emacspeak is nearly 20 years old)
 
 ;;}}}
 ;;{{{ requires
+(require 'cl)
 (require 'emacspeak-preamble)
+(require 'emacspeak-hide)
 (require 'gnus)
 (require 'gnus-art)
 (require 'gnus-sum)
-
-;; This may not be needed. It seems emacs version of gnus had 
-;; gnus-article-buffer as far back as emacs 21.
-(unless (and (symbolp 'gnus-article-buffer)
-             (boundp 'gnus-article-buffer))
-  (defvar gnus-article-buffer "*Article*"))
-
+(require 'gm-nnir) ; for smart GMail search
 ;;}}}
 ;;{{{  Customizations:
 
@@ -65,7 +62,7 @@
   :group 'gnus
   :prefix "emacspeak-gnus-")
 
-(defcustom emacspeak-gnus-punctuation-mode  'some
+(defcustom emacspeak-gnus-punctuation-mode  'all
   "Pronunciation mode to use for gnus buffers."
   :type '(choice
           (const  :tag "Ignore" nil)
@@ -73,6 +70,14 @@
           (const  :tag "all" all))
   :group 'emacspeak-gnus)
 
+(defcustom  emacspeak-gnus-large-article 100
+  "*Articles having more than
+emacspeak-gnus-large-article lines will be considered to be a large article.
+A large article is not spoken all at once;
+instead you hear only the first screenful."
+  :type 'integer
+  :group 'emacspeak-gnus 
+  )
 ;;; These customizations to gnus make it convenient to listen to news:
 ;;; You can read news mostly by using the four arrow keys.
 ;;; By default all article headers are hidden, so you hear the real news.
@@ -82,18 +87,15 @@
 (defun emacspeak-gnus-setup-keys ()
   "Setup Emacspeak keys."
   (declare (special gnus-summary-mode-map
-                    gnus-group-mode-map
+                    gnus-group-mmode-map
                     gnus-article-mode-map))
-  (when (boundp 'gnus-summary-mode-map))
-  (when (boundp 'gnus-article-mode-map)
-    )
-  (when (boundp 'gnus-group-mode-map))
   (define-key gnus-summary-mode-map "\C-t" 'gnus-summary-toggle-header)
-  (define-key gnus-summary-mode-map "T" 'gnus-summary-hide-all-headers )
-  (define-key gnus-summary-mode-map "t"
-    'gnus-summary-show-some-headers)
+  (define-key gnus-summary-mode-map "\M-T" 'emacspeak-gnus-summary-hide-all-headers )
+  (define-key gnus-summary-mode-map "t" 'emacspeak-gnus-summary-show-some-headers)
   (define-key gnus-summary-mode-map '[left] 'emacspeak-gnus-summary-catchup-quietly-and-exit)
   (define-key gnus-summary-mode-map '[right] 'gnus-summary-show-article)
+  (define-key  gnus-group-mode-map "?" 'gm-nnir-group-make-nnir-group)
+  (define-key gnus-group-mode-map "/" 'gm-nnir-group-make-gmail-group)
   (define-key gnus-group-mode-map "\C-n" 'gnus-group-next-group)
   (define-key gnus-group-mode-map [down] 'gnus-group-next-group)
   (define-key gnus-group-mode-map [up] 'gnus-group-prev-group)
@@ -107,7 +109,7 @@
 ;;}}}
 ;;{{{  Hiding headers
 
-(defvar  gnus-ignored-most-headers
+(defvar  emacspeak-gnus-ignored-most-headers
   (concat
    "^Path:\\|^Posting-Version:\\|^Article-I.D.:\\|^Expires:"
    "\\|^Date-Received:\\|^References:\\|^Control:\\|^Xref:"
@@ -120,22 +122,22 @@
    "\\|^Followup-To:\\|^Original-Cc:\\|^Reply-To:")
   "Article headers to ignore when only important article headers are to be
 spoken.
-See command \\[gnus-summary-show-some-headers].")
+See command \\[emacspeak-gnus-summary-show-some-headers].")
 (declaim (special gnus-ignored-headers))
 (setq gnus-ignored-headers "^.*:")
 (declaim (special gnus-visible-headers))
 (setq gnus-visible-headers "^Subject:")
 
-(defun gnus-summary-show-some-headers ()
+(defun emacspeak-gnus-summary-show-some-headers ()
   "Show only the important article headers,
 i.e. sender name, and subject."
   (interactive)
-  (declare (special gnus-ignored-most-headers )) 
-  (let ((gnus-ignored-headers gnus-ignored-most-headers ))
+  (declare (special emacspeak-gnus-ignored-most-headers )) 
+  (let ((gnus-ignored-headers emacspeak-gnus-ignored-most-headers ))
     (gnus-summary-toggle-header 1)
     (gnus-summary-toggle-header -1)))
 
-(defun gnus-summary-hide-all-headers()
+(defun emacspeak-gnus-summary-hide-all-headers()
   "Hide all headers in the article.
 Use this command if you don't want to listen to any article headers when
 reading news."
@@ -157,7 +159,6 @@ reading news."
                     gnus-article-buffer))
   (with-current-buffer gnus-article-buffer
     (goto-char (point-min))
-    (setq dtk-punctuation-mode 'some)
     (emacspeak-dtk-sync)
     (cond
      ((< (count-lines (point-min) (point-max))
@@ -208,6 +209,11 @@ reading news."
   (message "Gnus is ready ")
   (emacspeak-auditory-icon 'news))
 
+(defadvice nnheader-message-maybe (around emacspeak pre act comp)
+  "Silence emacspeak"
+  (let ((emacspeak-speak-messages nil))
+    ad-do-it))
+
 ;;}}}
 ;;{{{  Newsgroup selection
 
@@ -703,7 +709,11 @@ Produce an auditory icon if possible."
   (when (ems-interactive-p ) 
     (emacspeak-auditory-icon 'select-object)
     (emacspeak-gnus-summary-speak-subject )))
-
+(defadvice gnus-summary-hide-all-threads (after emacspeak pre act comp)
+  "Provide auditory feedback."
+  (when (ems-interactive-p)
+    (emacspeak-auditory-icon 'close-object)
+    (emacspeak-speak-line)))
 ;;}}}
 ;;{{{  Article reading
 
@@ -711,19 +721,16 @@ Produce an auditory icon if possible."
   "Catch up on all articles in current group."
   (interactive)
   (gnus-summary-catchup-and-exit t t)
-  (emacspeak-auditory-icon 'close-object))
-;;; helper function:
+  (emacspeak-auditory-icon 'close-object)
+  (emacspeak-speak-line))
 
-(defvar emacspeak-gnus-large-article 30 
-  "*Articles having more than
-emacspeak-gnus-large-article lines will be considered to be a large article.
-A large article is not spoken all at once;
-instead you hear only the first screenful.")
+;;; helper function:
 
 (defadvice gnus-summary-show-article (after emacspeak pre act)
   "Start speaking the article. "
   (when (ems-interactive-p )
     (emacspeak-auditory-icon 'open-object)
+    (emacspeak-hide-all-blocks-in-buffer)
     (emacspeak-gnus-speak-article-body)))
 
 (defadvice gnus-summary-next-page (after emacspeak pre act)
@@ -868,45 +875,21 @@ Helps to prevent words from being spelled instead of spoken."
   (dtk-speak "Downcased article body"))
 
 ;;}}}
-;;{{{ rdc: refreshing the pronunciation  and punctuation mode
+;;{{{ refreshing the pronunciation  and punctuation mode
 
-(add-hook 'gnus-article-mode-hook
-          (function (lambda ()
-                      (dtk-set-punctuations emacspeak-gnus-punctuation-mode)
-                      (emacspeak-pronounce-refresh-pronunciations))))
-
-(add-hook 'gnus-group-mode-hook
-          (function (lambda ()
-                      (dtk-set-punctuations emacspeak-gnus-punctuation-mode)
-                      (emacspeak-pronounce-refresh-pronunciations))))
-
-;; the following is for summary mode.  By default, the 
-;; summary mode hook is defined as gnus-agent-mode
-
-(add-hook 'gnus-agent-mode-hook
-          (function (lambda ()
-                      (dtk-set-punctuations emacspeak-gnus-punctuation-mode)
-                      (emacspeak-pronounce-refresh-pronunciations))))
-
-(add-hook 'gnus-article-edit-mode-hook
-          (function (lambda ()
-                      (dtk-set-punctuations emacspeak-gnus-punctuation-mode)
-                      (emacspeak-pronounce-refresh-pronunciations))))
-
-(add-hook 'gnus-category-mode-hook
-          (function (lambda ()
-                      (dtk-set-punctuations emacspeak-gnus-punctuation-mode)
-                      (emacspeak-pronounce-refresh-pronunciations))))
-
-(add-hook 'gnus-score-mode-hook
-          (function (lambda ()
-                      (dtk-set-punctuations emacspeak-gnus-punctuation-mode)
-                      (emacspeak-pronounce-refresh-pronunciations))))
-
-(add-hook 'gnus-server-mode-hook
-          (function (lambda ()
-                      (dtk-set-punctuations emacspeak-gnus-punctuation-mode)
-                      (emacspeak-pronounce-refresh-pronunciations))))
+(loop
+ for hook  in 
+ '(
+   gnus-article-mode-hook gnus-group-mode-hook gnus-summary-mode-hook
+                          gnus-agent-mode-hook  gnus-article-edit-mode-hook
+                          gnus-server-mode-hook gnus-category-mode-hook
+                          )
+ do
+ (add-hook
+  hook 
+  #'(lambda ()
+      (dtk-set-punctuations emacspeak-gnus-punctuation-mode)
+      (emacspeak-pronounce-refresh-pronunciations))))
 
 ;;}}}
 ;;{{{ rdc: mapping font faces to personalities 
@@ -926,8 +909,8 @@ Helps to prevent words from being spelled instead of spoken."
    (gnus-cite-1 voice-bolden-medium)
    (gnus-cite-2 voice-lighten) 
    (gnus-cite-3 voice-lighten-extra)
-   (gnus-cite-4 voice-bolden)
-   (gnus-cite-5 voice-bolden-medium)
+   (gnus-cite-4 voice-smoothen)
+   (gnus-cite-5 voice-smoothen-extra)
    (gnus-cite-6 voice-lighten)
    (gnus-cite-7 voice-lighten-extra)
    (gnus-cite-8 voice-bolden)
@@ -950,7 +933,7 @@ Helps to prevent words from being spelled instead of spoken."
    ;; on the same thing are given the same voice.  Any user that
    ;; uses low and high interest is sufficiently advanced to change
    ;; the voice to his own preferences
-   (gnus-summary-normal-read voice-bolden)
+   (gnus-summary-normal-read voice-smoothen)
    (gnus-summary-high-read voice-bolden)
    (gnus-summary-low-read voice-bolden)
    (gnus-summary-normal-ticked voice-brighten-extra)
@@ -1002,6 +985,7 @@ Helps to prevent words from being spelled instead of spoken."
    (gnus-server-denied voice-bolden-extra)
    (gnus-server-offline voice-animate)
    (gnus-server-opened voice-lighten)))
+
 ;;}}}
 (provide 'emacspeak-gnus)
 ;;{{{  end of file 
