@@ -1,5 +1,5 @@
 ;;; emacspeak-m-player.el --- Control mplayer from Emacs
-;;; $Id: emacspeak-m-player.el 8574 2013-11-24 02:01:07Z tv.raman.tv $
+;;; $Id: emacspeak-m-player.el 9079 2014-04-17 15:41:09Z tv.raman.tv $
 ;;; $Author: tv.raman.tv $
 ;;; Description: Controlling mplayer from emacs 
 ;;; Keywords: Emacspeak, m-player streaming media 
@@ -195,10 +195,12 @@ on a specific directory."
   (declare (special emacspeak-m-player-process))
   (cond
    ((and emacspeak-m-player-process
-         (eq 'run (process-status emacspeak-m-player-process)))
+         (eq 'run (process-status emacspeak-m-player-process))
+         (buffer-live-p (process-buffer emacspeak-m-player-process)))
     (with-current-buffer (process-buffer emacspeak-m-player-process)
       (call-interactively 'emacspeak-m-player-command)))
-   (t  (call-interactively 'emacspeak-m-player))))
+   (t
+    (call-interactively 'emacspeak-m-player))))
 
 (defun emacspeak-m-player-command (key)
   "Invoke MPlayer commands."
@@ -351,10 +353,11 @@ The player is placed in a buffer in emacspeak-m-player-mode."
             (nconc options (list resource)))))
     (save-current-buffer
       (setq emacspeak-m-player-process
-            (apply 'start-process "M PLayer" buffer
+            (apply 'start-process "MPLayer" buffer
                    emacspeak-m-player-program options))
       (set-buffer buffer)
-      (emacspeak-m-player-mode))))
+      (emacspeak-m-player-mode)
+      (message "MPlayer opened  %s" resource))))
 
 ;;;###autoload
 (defun emacspeak-m-player-shuffle ()
