@@ -1,5 +1,5 @@
 ;;; emacspeak-org.el --- Speech-enable org
-;;; $Id: emacspeak-org.el 8395 2013-08-21 15:20:06Z tv.raman.tv $
+;;; $Id: emacspeak-org.el 8874 2014-02-26 17:05:50Z tv.raman.tv $
 ;;; $Author: tv.raman.tv $
 ;;; Description:  Emacspeak front-end for ORG
 ;;; Keywords: Emacspeak, org
@@ -45,7 +45,7 @@
 ;;;  Org allows you to keep organized notes and todo lists.
 ;;; Homepage: http://www.astro.uva.nl/~dominik/Tools/org/
 ;;; or http://orgmode.org/
-;;; 
+;;;
 ;;; Code:
 
 ;;}}}
@@ -142,6 +142,7 @@
                            org-meta-return
                            org-shiftmetaleft org-shiftmetaright org-shiftmetaup org-shiftmetadown
                            org-mark-element org-mark-subtree
+                           org-agenda-forward-block org-agenda-backward-block
                            )
       do
       (eval
@@ -166,11 +167,10 @@
           (when (ems-interactive-p )
             (cond
              ((org-at-table-p 'any)
-              (let ((emacspeak-show-point t))
-                (skip-syntax-forward " ")
-                (emacspeak-speak-line)
-                (emacspeak-auditory-icon 'large-movement)))
-             (t (emacspeak-auditory-icon 'select-object)))))))
+              (emacspeak-org-table-speak-current-element))
+             (t
+              (emacspeak-speak-line)
+              (emacspeak-auditory-icon 'select-object)))))))xrjp
 
 (defadvice org-overview (after emacspeak pre act comp)
   "Provide auditory feedback."
@@ -354,6 +354,13 @@
 
 ;;}}}
 ;;{{{ import/export:
+;;; Work In Progress:
+;;; Need to be able to use Emacspeak keys within the dispatcher.
+
+                                        ;(defadvice org-export--dispatch-action (around emacspeak (prompt allowed-keys entries options first-key expertp)  pre act comp)
+                                        ;"Enable Emacspeak keys."
+                                        ;(ad-set-argument '(prompt allowed-keys entries options first-key expertp) 1  (pushnew  5 (ad-get-arg 1)))
+                                        ;ad-do-it)
 
 ;;}}}
 ;;{{{ org-goto fixup:
@@ -434,7 +441,12 @@
 (defadvice org-return (after emacspeak pre act comp)
   "Provide auditory feedback."
   (when (ems-interactive-p )
-    (emacspeak-speak-line)))
+    (cond
+     ((org-at-table-p 'any)
+      (emacspeak-org-table-speak-current-element))
+     (t
+      (emacspeak-speak-line)
+      (emacspeak-auditory-icon 'select-object)))))
 
 ;;}}}
 ;;{{{ mode hook:
@@ -448,7 +460,7 @@
 
 (add-hook 'org-mode-hook 'emacspeak-org-mode-setup)
 
-;;; advice end-of-line here to call org specific action 
+;;; advice end-of-line here to call org specific action
 (defadvice end-of-line (after emacspeak-org pre act comp)
   "Call org specific actions in org mode."
   (when (and (ems-interactive-p )
@@ -481,7 +493,7 @@
       (eval
        `(defadvice ,f (around emacspeak pre act comp)
           "Avoid outline errors bubbling up."
-          
+
           (ems-with-errors-silenced ad-do-it))))
 
 ;;}}}
@@ -527,6 +539,20 @@
   "Provide auditory feedback."
   (emacspeak-auditory-icon 'close-object))
 
+;;;###autoload
+(defun emacspeak-org-table-speak-current-element ()
+  "echoes current table element"
+  (interactive)
+  (dtk-speak-and-echo (org-table-get-field)))
+(loop
+ for f in
+ '(org-table-next-field org-table-previous-field)
+ do
+ (eval
+  `(defadvice ,f  (after emacspeak pre act comp)
+     "Provide auditory feedback."
+     (emacspeak-org-table-speak-current-element))))
+
 ;;}}}
 (provide 'emacspeak-org)
 ;;{{{ end of file
