@@ -1,6 +1,6 @@
 ;;; emacspeak-tetris.el --- Speech enable game of Tetris
-;;; $Id: emacspeak-tetris.el,v 23.505 2005/11/25 16:30:50 raman Exp $
-;;; $Author: raman $ 
+;;; $Id: emacspeak-tetris.el 8146 2013-02-09 20:05:08Z tv.raman.tv $
+;;; $Author: tv.raman.tv $ 
 ;;; Description: Auditory interface to tetris
 ;;; Keywords: Emacspeak, Speak, Spoken Output, tetris
 ;;{{{  LCD Archive entry: 
@@ -8,15 +8,15 @@
 ;;; LCD Archive Entry:
 ;;; emacspeak| T. V. Raman |raman@cs.cornell.edu 
 ;;; A speech interface to Emacs |
-;;; $Date: 2005/11/25 16:30:50 $ |
-;;;  $Revision: 23.505 $ | 
+;;; $Date: 2007-08-25 18:28:19 -0700 (Sat, 25 Aug 2007) $ |
+;;;  $Revision: 4532 $ | 
 ;;; Location undetermined
 ;;;
 
 ;;}}}
 ;;{{{  Copyright:
 
-;;; Copyright (c) 1995 -- 2004, T. V. Raman
+;;; Copyright (c) 1995 -- 2011, T. V. Raman
 ;;; All Rights Reserved. 
 ;;;
 ;;; This file is not part of GNU Emacs, but the same permissions apply.
@@ -41,9 +41,6 @@
 ;;{{{  Required modules
 
 (require 'emacspeak-preamble)
-(condition-case nil
-    (require 'tetris)		 ;FC2 Emacs doesn't contain tetris.el?
-  )
 ;;}}}
 ;;{{{  Introduction 
 
@@ -64,8 +61,8 @@
     (setq emacspeak-tetris-pronunciations-defined t)
     (mapcar
      #'(lambda (entry)
-	 (emacspeak-pronounce-add-dictionary-entry 'tetris-mode
-						   (car entry) (cdr entry)))
+         (emacspeak-pronounce-add-dictionary-entry 'tetris-mode
+                                                   (car entry) (cdr entry)))
      '(("" . " 1 ")
        ("" . " 6 ")
        ("" . " 7 ")
@@ -74,7 +71,7 @@
        ("" . " 3 ")
        ("" . " 2 ")
        (" " . "-")
-       ("" . "")			;border char
+       ("" . "")                      ;border char
        ("." . ""))))
   (when (or (not (boundp 'emacspeak-pronounce-pronunciation-table))
             (not emacspeak-pronounce-pronunciation-table))
@@ -153,8 +150,8 @@
   (dtk-speak
    (format "%s %s at rotation  %s next is %s"
            (if emacspeak-tetris-filled-a-row 
-	       tetris-n-rows
-	     " ")
+               tetris-n-rows
+             " ")
            (emacspeak-tetris-shape-name (1+ tetris-shape))
            tetris-rot
            (emacspeak-tetris-shape-name (1+ tetris-next-shape))))
@@ -176,7 +173,7 @@
                      tetris-shape tetris-rot))
   (message "%s at %s %s  at rotation %s"
            (emacspeak-tetris-shape-name (1+ tetris-shape))
-	   tetris-pos-x
+           tetris-pos-x
            tetris-pos-y
            tetris-rot))
 
@@ -204,6 +201,7 @@
 going on. Reduce it as you get better.")
 
 (defsubst emacspeak-tetris-tick-period ()
+  (declare (special emacspeak-tetris-tick-period))
   emacspeak-tetris-tick-period)
 
 (defalias 'tetris-get-tick-period 'emacspeak-tetris-tick-period)
@@ -325,7 +323,7 @@ Tetris with speech feedback alone requires a lot of
 concentration and the game is a good mental challenge. "
   (declare (special tetris-tick-period
                     emacspeak-tetris-blank-row))
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (setq tetris-tick-period emacspeak-tetris-tick-period)
     (setq tetris-width emacspeak-tetris-width)
     (setq emacspeak-tetris-blank-row (emacspeak-tetris-blank-row))
@@ -340,7 +338,7 @@ concentration and the game is a good mental challenge. "
 (defadvice tetris-start-game (after emacspeak pre act comp)
   "Provide auditory feedback"
   (declare (special emacspeak-tetris-blank-row))
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'open-object)
     (setq tetris-width emacspeak-tetris-width)
     (setq emacspeak-tetris-blank-row (emacspeak-tetris-blank-row))
@@ -348,7 +346,7 @@ concentration and the game is a good mental challenge. "
 
 (defadvice tetris-end-game (after emacspeak pre act comp)
   "Provide auditory feedback"
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'close-object)
     (message "Ending current game")))
 
@@ -358,42 +356,42 @@ concentration and the game is a good mental challenge. "
 
 (defadvice tetris-rotate-next (after emacspeak pre act comp)
   "Provide auditory feedback"
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-tetris-speak-current-shape)))
 
 (defadvice tetris-rotate-prev (after emacspeak pre act comp)
   "Provide auditory feedback"
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-tetris-speak-current-shape)))
 
 (defadvice tetris-move-left-edge (after emacspeak pre act comp)
   "Speak coordinates"
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-tetris-speak-column)))
 
 (defadvice tetris-move-right-edge (after emacspeak pre act comp)
   "Speak coordinates"
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-tetris-speak-column)))
 
 (defadvice tetris-move-to-x-pos (after emacspeak pre act comp)
   "Speak coordinates"
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-tetris-speak-column)))
 
 (defadvice tetris-move-left (after emacspeak pre act comp)
   "Speak coordinates"
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-tetris-speak-column)))
 
 (defadvice tetris-move-right (after emacspeak pre act comp)
   "Speak coordinates"
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-tetris-speak-column)))
 
 (defadvice tetris-move-bottom (after emacspeak pre act comp)
   "Provide auditory feedback as the tile falls"
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'close-object)))
 (defvar emacspeak-tetris-filled-a-row nil
   "Temporary flag indicating if we just filled a row.")
@@ -421,10 +419,10 @@ concentration and the game is a good mental challenge. "
   (define-key tetris-mode-map "N" 'tetris-start-game)
   (define-key  tetris-mode-map "c" 'emacspeak-tetris-speak-row)
   (loop for i from 0 to 9
-	do
-	(define-key tetris-mode-map
-	  (format "%s" i)
-	  'tetris-move-to-x-pos))
+        do
+        (define-key tetris-mode-map
+          (format "%s" i)
+          'tetris-move-to-x-pos))
   (define-key tetris-mode-map "a" 'tetris-move-left-edge)
   (define-key tetris-mode-map "e" 'tetris-move-right-edge)
   (define-key tetris-mode-map "l" 'tetris-move-right)
@@ -478,18 +476,18 @@ concentration and the game is a good mental challenge. "
       (setq hit (tetris-test-shape)))
     (tetris-draw-shape)))
 
-a(defun tetris-move-right-edge ()
-   "Moves the shape to the right edge  of the playing area"
-   (interactive)
-   (declare (special tetris-pos-x tetris-width))
-   (let ((hit nil)
-         (max(- tetris-width (tetris-shape-width))))
-     (tetris-erase-shape)
-     (while(and (< tetris-pos-x max)
-                (not hit))
-       (setq tetris-pos-x (1+ tetris-pos-x))
-       (setq hit (tetris-test-shape)))
-     (tetris-draw-shape)))
+(defun tetris-move-right-edge ()
+  "Moves the shape to the right edge  of the playing area"
+  (interactive)
+  (declare (special tetris-pos-x tetris-width))
+  (let ((hit nil)
+        (max(- tetris-width (tetris-shape-width))))
+    (tetris-erase-shape)
+    (while(and (< tetris-pos-x max)
+               (not hit))
+      (setq tetris-pos-x (1+ tetris-pos-x))
+      (setq hit (tetris-test-shape)))
+    (tetris-draw-shape)))
 
 (defun tetris-move-to-x-pos ()
   "Moves the shape to a specified x position if possible"
@@ -533,7 +531,7 @@ a(defun tetris-move-right-edge ()
     (setq result
           (loop for y from tetris-top-left-y
                 to (+ tetris-height tetris-top-left-y)
-		collect (gamegrid-get-cell x y)))
+                collect (gamegrid-get-cell x y)))
     (mapconcat 'char-to-string result "")))
 
 (defun emacspeak-tetris-speak-column (&optional x)
@@ -544,12 +542,12 @@ a(defun tetris-move-right-edge ()
   (dtk-speak (emacspeak-tetris-get-column-contents x)))
 
 ;;}}}
-(provide 'emacspeak-tetris)o
+(provide 'emacspeak-tetris)
 ;;{{{ end of file 
 
 ;;; local variables:
 ;;; folded-file: t
-;;; byte-compile-dynamic: t
+;;; byte-compile-dynamic: nil
 ;;; end: 
 
 ;;}}}
