@@ -1,5 +1,5 @@
 ;;; emacspeak-webutils.el --- Common Web Utilities For Emacspeak
-;;; $Id: emacspeak-webutils.el 5362 2007-11-18 04:22:32Z tv.raman.tv $
+;;; $Id: emacspeak-webutils.el 9107 2014-04-27 15:17:48Z tv.raman.tv $
 ;;; $Author: tv.raman.tv $
 ;;; Description:  Emacspeak Webutils
 ;;; Keywords: Emacspeak, web
@@ -8,7 +8,7 @@
 ;;; LCD Archive Entry:
 ;;; emacspeak| T. V. Raman |raman@cs.cornell.edu
 ;;; A speech interface to Emacs |
-;;; $Date: 2007-11-17 20:22:32 -0800 (Sat, 17 Nov 2007) $ |
+;;; $Date: 2008-08-14 11:23:31 -0700 (Thu, 14 Aug 2008) $ |
 ;;;  $Revision: 4634 $ |
 ;;; Location undetermined
 ;;;
@@ -16,7 +16,7 @@
 ;;}}}
 ;;{{{  Copyright:
 
-;;; Copyright (C) 1999 T. V. Raman <raman@cs.cornell.edu>
+;;; Copyright (C) 1999, 2011 T. V. Raman <raman@cs.cornell.edu>
 ;;; All Rights Reserved.
 ;;;
 ;;; This file is not part of GNU Emacs, but the same permissions apply.
@@ -51,10 +51,30 @@
 ;;; Code:
 (require 'cl)
 (declaim  (optimize  (safety 0) (speed 3)))
-(require 'backquote)
 (require 'emacspeak-preamble)
 (require 'url)
+(require 'gfeeds)
 (require 'browse-url)
+;;}}}
+;;{{{ Utility: Render HTML To String
+;;;###autoload
+(defsubst emacspeak-webutils-html-string (html-string)
+  "Return formatted string."
+  (or (require 'shr) (error "Need  emacs 24.4"))
+  (with-temp-buffer 
+    (insert html-string)
+    (shr-render-region  (point-min) (point-max))
+    (buffer-string)))
+
+;;}}}
+;;{{{ Fix bug in url-cookie
+
+(defadvice url-cookie-write-file (around fix-write-bug pre act comp)
+  "Fix bug in url-cookie-write-file."
+  (let ((print-length nil)
+        (print-level nil))
+    ad-do-it))
+
 ;;}}}
 ;;{{{ keymap: web-prefix
 (define-prefix-command 'emacspeak-web-prefix)
@@ -80,9 +100,12 @@ Note that the Web browser should reset this hook after using it.")
   "Use web post process hook."
   (declare (special emacspeak-web-post-process-hook))
   (when     emacspeak-web-post-process-hook
-    (unwind-protect
-        (run-hooks  'emacspeak-web-post-process-hook)
-      (setq emacspeak-web-post-process-hook nil))))
+    (condition-case nil
+        (let ((inhibit-read-only t))
+          (run-hooks  'emacspeak-web-post-process-hook))
+      (error  (message "Caught error  in post-process hook.")
+              (setq emacspeak-web-post-process-hook nil)))
+    (setq emacspeak-web-post-process-hook nil)))
 
 ;;}}}
 ;;{{{ Helpers:
@@ -119,16 +142,47 @@ Note that the Web browser should reset this hook after using it.")
         (eq browse-url-browser-function 'w3m-browse-url)))
 
 (defsubst emacspeak-webutils-autospeak()
-  "Setup post process hook to speak the Web page when rendered."
-  (add-hook 'emacspeak-web-post-process-hook
-            #'(lambda nil
-                (emacspeak-speak-buffer))))
+  "Setup post process hook to speak the Web page when rendered.
+Forward punctuation and rate  settings to resulting buffer."
+  (lexical-let
+      ((p dtk-punctuation-mode)
+       (r dtk-speech-rate))
+    (add-hook 'emacspeak-web-post-process-hook
+              #'(lambda nil
+                  (declare (special emacspeak-we-xpath-filter))
+                  (let ((inhibit-read-only t))
+                    (dtk-set-punctuations p)
+                    (dtk-set-rate r)
+                    (emacspeak-dtk-sync)
+                    (setq emacspeak-we-xpath-filter
+                          emacspeak-we-paragraphs-xpath-filter)
+                    (emacspeak-speak-buffer)))
+              'at-end)))
+
+(defsubst emacspeak-webutils-cache-google-query(query)
+  "Setup post process hook to cache google query when rendered."
+  (declare (special emacspeak-google-query))
+  (let ((cache
+         (eval `(function
+                 (lambda nil
+                   (setq emacspeak-google-query ,query))))))
+    (add-hook 'emacspeak-web-post-process-hook cache 'at-end)))
+
+(defsubst emacspeak-webutils-cache-google-toolbelt(belt)
+  "Setup post process hook to cache google toolbelt when rendered."
+  (declare (special emacspeak-google-toolbelt))
+  (let ((cache
+         (eval `(function
+                 (lambda nil
+                   (setq emacspeak-google-toolbelt' ,belt))))))
+    (add-hook 'emacspeak-web-post-process-hook cache 'at-end)))
 
 (defsubst emacspeak-webutils-browser-check ()
   "Check to see if functions are called from a browser buffer"
   (declare (special major-mode))
   (unless (or (eq major-mode 'w3-mode)
-              (eq major-mode 'w3m-mode))
+              (eq major-mode 'w3m-mode)
+              (eq major-mode 'eww-mode))
     (error "This command cannot be used outside browser buffers.")))
 
 (defsubst emacspeak-webutils-read-url ( )
@@ -172,65 +226,20 @@ SPEAKER is a function to call to speak relevant information.
 ARGS specifies additional arguments to SPEAKER if any."
   (declare (special emacspeak-web-post-process-hook))
   (when (emacspeak-webutils-supported-p)
-    (add-hook  'emacspeak-web-post-process-hook
-               (eval
-                `(function
-                  (lambda nil
-                    (cond
-                     ((search-forward ,locator nil t)
-                      (recenter 0)
-                      (apply(quote ,speaker) ,args))
-                     (t (message "Your search appears to have failed.")))))))))
-
-;;}}}
-;;{{{ google suggest helper:
-
-;;; Get search completions from Google
-;;; Inspired by code found on Emacs Wiki:
-;;; http://www.emacswiki.org/cgi-bin/wiki/emacs-w3m#WThreeM
-;;; Changed to using csv=true thanks to Ami Fishman
-;;; As a result, this version is  more efficient
-(defvar emacspeak-webutils-google-suggest-command
-  "curl -s\
- 'http://www.google.com/complete/search?csv=true&qu=%s' \
- | head -2 | tail -1 \
-| sed -e 's/\"//g'"
-  "Command that gets suggestions from Google.")
-
-(defvar emacspeak-webutils-google-suggest-json
-  "curl -s\
- 'http://www.google.com/complete/search?json=true&qu=%s' "
-  "URL  that gets suggestions from Google as JSON.")
-
-(defsubst emacspeak-webutils-google-suggest (input)
-  "Get completion list from Google Suggest."
-  (declare (special emacspeak-webutils-google-suggest-json))
-  (let ((buffer (get-buffer-create "*Google AutoComplete*")))
-    (save-current-buffer
-      (set-buffer buffer)
-      (setq buffer-undo-list t)
-      (erase-buffer)
-      (shell-command
-       (format emacspeak-webutils-google-suggest-json
-               (emacspeak-url-encode input))
-       buffer)
-      (goto-char (point-min))
-      ;; A JSON array is a vector.
-      ;; read it, filter the comma separators found as symbols.
-      (delq'\,
-       (append                          ; vector->list
-        (aref (read (current-buffer)) 2)
-        nil)))))
-
-(defsubst emacspeak-webutils-google-autocomplete (&optional prompt)
-  "Read user input using Google Suggest for auto-completion."
-  (let ((minibuffer-completing-file-name t) ;; so we can type
-        ;; spaces
-        (completion-ignore-case t))
-    (emacspeak-url-encode
-    (completing-read
-     (or prompt "Google: ")
-                     (dynamic-completion-table emacspeak-webutils-google-suggest)))))
+    (add-hook
+     'emacspeak-web-post-process-hook
+     (eval
+      `(function
+        (lambda nil
+          (let ((inhibit-read-only t))
+            (condition-case nil
+                (cond
+                 ((search-forward ,locator nil t)
+                  (recenter 0)
+                  (apply(quote ,speaker) ,args))
+                 (t (message "Your search appears to have failed.")))
+              (error nil))))))
+     'at-end)))
 
 ;;}}}
 ;;{{{ helper macros:
@@ -246,34 +255,36 @@ ARGS specifies additional arguments to SPEAKER if any."
        (add-hook 'emacspeak-web-post-process-hook
                  #'(lambda ()
                      (declare (special emacspeak-we-xsl-p))
-                     (setq emacspeak-we-xsl-p t))))
+                     (setq emacspeak-we-xsl-p t))
+                 'append))
      ,@body))
 
 (defmacro emacspeak-webutils-with-xsl-environment (style params options  &rest body)
   "Execute body with XSL turned on
 and xsl environment specified by style, params and options."
-  `(let ((save-flag ,emacspeak-we-xsl-p)
-         (save-options ,emacspeak-xslt-options)
-         (save-style ,emacspeak-we-xsl-transform)
-         (save-params ,emacspeak-we-xsl-params))
-     (setq emacspeak-we-xsl-p t
-           emacspeak-xslt-options ,options
-           emacspeak-we-xsl-transform ,style
-           emacspeak-we-xsl-params ,params)
+  `(progn
      (add-hook
       'emacspeak-web-post-process-hook
       (eval
        `(function
          (lambda ()
-           (declare (special emacspeak-we-xsl-p
-                             emacspeak-we-xsl-transform
-                             emacspeak-xslt-options
-                             emacspeak-we-xsl-params))
-           (setq emacspeak-we-xsl-p ,save-flag
-                 emacspeak-xslt-options ,save-options
-                 emacspeak-we-xsl-transform ,save-style
-                 emacspeak-we-xsl-params ,save-params)))))
-     ,@body))
+           (declare (special emacspeak-we-xsl-p emacspeak-we-xsl-transform
+                             emacspeak-xslt-options emacspeak-we-xsl-params))
+           (setq emacspeak-we-xsl-p ,emacspeak-we-xsl-p
+                 emacspeak-xslt-options ,emacspeak-xslt-options
+                 emacspeak-we-xsl-transform ,emacspeak-we-xsl-transform
+                 emacspeak-we-xsl-params ,emacspeak-we-xsl-params))))
+      'append)
+     (setq emacspeak-we-xsl-p t
+           emacspeak-xslt-options ,options
+           emacspeak-we-xsl-transform ,style
+           emacspeak-we-xsl-params ,params)
+     (condition-case nil
+         (progn ,@body)
+       (error (setq emacspeak-we-xsl-p ,emacspeak-we-xsl-p
+                    emacspeak-xslt-options ,emacspeak-xslt-options
+                    emacspeak-we-xsl-transform ,emacspeak-we-xsl-transform
+                    emacspeak-we-xsl-params ,emacspeak-we-xsl-params)))))
 
 ;;}}}
 ;;{{{ variables
@@ -293,6 +304,26 @@ and xsl environment specified by style, params and options."
 (make-variable-buffer-local 'emacspeak-webutils-url-at-point)
 (make-variable-buffer-local 'emacspeak-webutils-current-url)
 
+;;}}}
+;;{{{ Properties from HTML stack:
+
+(defsubst emacspeak-webutils-property-names-from-html-stack (html-stack)
+  "Returns list of attributes from HTML stack."
+  (delete nil
+          (loop for e in html-stack
+                append
+                (mapcar 'car (rest e)))))
+
+(defun emacspeak-webutils-get-property-from-html-stack (html-stack prop)
+  "Extract and return list of prop values from HTML  stack.
+Stack is a list of the form ((element-name (attribute-alist)))."
+  (let ((props nil))
+    (loop for element in html-stack
+          do
+          (push (cdr (assoc prop (rest element)))
+                props))
+    (nreverse (delq nil props))))
+
 ;;}}}
 ;;{{{  google tools
 
@@ -312,13 +343,11 @@ current page."
 With a prefix argument, extracts url under point."
   (interactive "P")
   (emacspeak-webutils-browser-check)
-  (emacspeak-websearch-google
-   (format "cache:%s"
+  (browse-url
+   (format "http://webcache.googleusercontent.com/search?q=cache:%s"
            (cond
-            ((null prefix)
-             (funcall emacspeak-webutils-current-url))
-            (t
-             (funcall emacspeak-webutils-url-at-point))))))
+            ((null prefix) (funcall emacspeak-webutils-current-url))
+            (t (funcall emacspeak-webutils-url-at-point))))))
 
 ;;;###autoload
 (defun emacspeak-webutils-google-on-this-site ()
@@ -362,6 +391,13 @@ With a prefix argument, extracts url under point."
       (let* ((args (substring url (length prefix)))
              (arg-alist (url-parse-args (subst-char-in-string ?& ?\; args))))
         (url-unhex-string (cdr (assoc "u" arg-alist)))))))
+;;;###autoload 
+(defsubst emacspeak-webutils-transcode-this-url-via-google (url)
+  "Transcode specified url via Google."
+  (declare (special emacspeak-webutils-google-transcoder-url))
+  (browse-url
+   (format emacspeak-webutils-google-transcoder-url
+           (emacspeak-url-encode url))))
 
 ;;;###autoload
 (defun emacspeak-webutils-transcode-via-google (&optional untranscode)
@@ -374,10 +410,7 @@ With a prefix argument, extracts url under point."
   (let ((url-mime-encoding-string "gzip"))
     (cond
      ((null untranscode)
-      (browse-url
-       (format emacspeak-webutils-google-transcoder-url
-               (emacspeak-url-encode
-                (funcall emacspeak-webutils-url-at-point)))))
+      (emacspeak-webutils-transcode-this-url-via-google (funcall emacspeak-webutils-url-at-point)))
      (t
       (let ((plain-url (emacspeak-webutils-transcoded-to-plain-url (funcall emacspeak-webutils-url-at-point))))
         (when plain-url
@@ -393,9 +426,8 @@ With a prefix argument, extracts url under point."
   ;; removing the above line makes the untranscode work
   (cond
    ((null untranscode)
-    (browse-url
-     (format emacspeak-webutils-google-transcoder-url
-             (emacspeak-url-encode (funcall emacspeak-webutils-current-url)))))
+    (emacspeak-webutils-transcode-this-url-via-google
+     (funcall emacspeak-webutils-current-url)))
    (t
     (let ((plain-url (emacspeak-webutils-transcoded-to-plain-url (funcall emacspeak-webutils-current-url))))
       (when plain-url
@@ -424,209 +456,36 @@ instances."
       (error "Title not found in body."))))
 
 ;;;###autoload
-(defun emacspeak-webutils-play-media-at-point ()
-  "Play media url under point "
-  (interactive )
-  (declare (special emacspeak-media-player))
-  (let ((url (funcall emacspeak-webutils-url-at-point)))
+(defun emacspeak-webutils-play-media-at-point (&optional  playlist-p)
+  "Play media url under point.
+Optional interactive prefix arg `playlist-p' says to treat the link as a playlist. "
+  (interactive "P" )
+  (let ((url
+         (if emacspeak-webutils-url-at-point
+             (funcall emacspeak-webutils-url-at-point)
+           (browse-url-url-at-point))))
     (message "Playing media  URL under point")
-    (funcall emacspeak-media-player  url
-	     nil 'noselect)))
+    (funcall  emacspeak-media-player  url  playlist-p)))
 
 ;;;###autoload
-(defun emacspeak-webutils-view-feed-via-google-reader ()
-  "Pulls feed under point via Google Reader."
-  (interactive)
-  (let ((feed (funcall emacspeak-webutils-url-at-point)))
-    (cond
-     ((null feed) (error "No url under point."))
-     (t (emacspeak-webutils-atom-display
-         (format
-          "http://www.google.com/reader/public/atom/feed/%s?n=20"
-          (emacspeak-url-encode feed)))))))
-;;;###autoload
 (defun emacspeak-webutils-open-in-other-browser ()
-  "Opens link in alternate browser.
- If using default browser is w3, uses w3m and vice-versa"
+  "Opens link in alternate browser."
   (interactive)
   (declare (special major-mode
                     w3-mode
-                    w3m-mode))
+                    eww-mode))
   (emacspeak-webutils-browser-check)
   (if (eq major-mode 'w3-mode)
-      (w3m-browse-url  (funcall emacspeak-webutils-url-at-point))
+      (eww-browse-url  (funcall emacspeak-webutils-url-at-point))
     (browse-url-w3 (funcall emacspeak-webutils-url-at-point))))
 
-;;}}}
-;;{{{ display authenticated feeds:
-
-(defun emacspeak-webutils-feed-display(feed-url style &optional speak)
-  "Fetch feed via Emacs and display using xsltproc."
-  (let ((buffer (url-retrieve-synchronously feed-url))
-        (emacspeak-xslt-options nil))
-    (when speak (emacspeak-webutils-autospeak))
-    (cond
-     ((null buffer)
-      (message "Nothing to display."))
-     (t
-      (emacspeak-webutils-without-xsl
-       (save-excursion
-         (set-buffer buffer)
-         (goto-char (point-min))
-         (search-forward "\n\n")
-         (delete-region (point-min) (point))
-                                        ;(decode-coding-region (point-min) (point-max) 'utf-8)
-         (emacspeak-xslt-region style
-                                (point-min) (point-max))
-         (browse-url-of-buffer)))))))
-
-;;;###autoload
-(defun emacspeak-webutils-rss-display (feed-url )
-  "Display RSS feed."
-  (interactive
-   (list
-    (emacspeak-webutils-read-this-url)))
-  (emacspeak-webutils-autospeak)
-  (emacspeak-webutils-feed-display feed-url
-                                   (emacspeak-xslt-get "rss.xsl")))
-
-;;;###autoload
-(defun emacspeak-webutils-atom-display (feed-url )
-  "Display ATOM feed."
-  (interactive (list (emacspeak-webutils-read-this-url)))
-  (declare (special emacspeak-atom-view-xsl))
-  (emacspeak-webutils-autospeak)
-  (emacspeak-webutils-feed-display feed-url
-                                   emacspeak-atom-view-xsl))
-
-;;;###autoload
-(defun emacspeak-webutils-fv (feed-url )
-  "Display RSS or ATOM feed."
-  (interactive (list (emacspeak-webutils-read-this-url)))
-  (emacspeak-auditory-icon 'select-object)
-  (emacspeak-webutils-autospeak)
-  (emacspeak-webutils-feed-display feed-url
-                                   (emacspeak-xslt-get "fv.xsl")))
-
-;;}}}
-;;{{{ RSS:
-;;{{{ RSS feed cache
-
-;;;###autoload
-(defgroup emacspeak-rss nil
-  "RSS Feeds for the Emacspeak desktop."
-  :group 'emacspeak)
-
-(defcustom emacspeak-rss-feeds
-  '(
-    ("Wired News" "http://www.wired.com/news_drop/netcenter/netcenter.rdf")
-    ("BBC News"  "http://www.bbc.co.uk/syndication/feeds/news/ukfs_news/front_page/rss091.xml")
-    ("CNet Tech News"  "http://rss.com.com/2547-12-0-5.xml")
-    ("XML.COM"  "http://www.xml.com/xml/news.rss")
-    )
-  "Table of RSS feeds."
-  :type '(repeat
-          (list :tag "RSS Feed"
-                (string :tag "Title")
-                (string :tag "URI")))
-  :group 'emacspeak-rss)
-
-;;}}}
-;;{{{  view feed
-(defcustom emacspeak-rss-unescape-html t
-  "Fix malformed  XML that results from sites attempting to
-unescape HTML tags."
-  :type 'boolean
-  :group 'emacspeak-rss)
-
-;;;###autoload
-
-;;;###autoload
-(defun emacspeak-opml-display (opml-url &optional speak)
-  "Retrieve and display OPML  URL."
-  (interactive
-   (list
-    (car (browse-url-interactive-arg "OPML  URL: "))
-    (or (interactive-p)
-        current-prefix-arg)))
-  (emacspeak-webutils-feed-display
-   (emacspeak-xslt-get "opml.xsl")
-   opml-url
-   speak))
-
-;;;###autoload
-(defun emacspeak-rss-browse (feed)
-  "Browse specified RSS feed."
-  (interactive
-   (list
-    (let ((completion-ignore-case t))
-      (completing-read "Feed:"
-                       emacspeak-rss-feeds))))
-  (let ((uri (cadr
-              (assoc feed emacspeak-rss-feeds))))
-    (emacspeak-webutils-rss-display uri )))
-
-;;}}}
-;;}}}
-;;{{{ ATOM:
-;;{{{ ATOM feed cache
-
-;;;###autoload
-(defgroup emacspeak-atom nil
-  "ATOM Feeds for the Emacspeak desktop."
-  :group 'emacspeak)
-
-;;;###autoload
-(defcustom emacspeak-atom-feeds
-  nil
-  "Table of ATOM feeds."
-  :type '(repeat
-          (list :tag "ATOM Feed"
-                (string :tag "Title")
-                (string :tag "URI")))
-  :group 'emacspeak-atom)
-
-;;}}}
-;;{{{  view feed
-
-(defvar emacspeak-atom-legacy
-  (expand-file-name "legacy-atom.xsl" emacspeak-xslt-directory)
-  "Legacy Atom support.")
-
-(defvar emacspeak-atom-modern
-  (expand-file-name "atom-view.xsl" emacspeak-xslt-directory)
-  "Modern Atom support.")
-
-(defcustom emacspeak-atom-view-xsl
-  emacspeak-atom-legacy
-  "XSL stylesheet used for viewing Atom Feeds."
-  :type '(choice
-          (string :tag "Legacy"  emacspeak-atom-legacy)
-          (string :tag "Modern" emacspeak-atom-modern))
-  :group 'emacspeak-xsl)
-
-;;;###autoload
-
-;;;###autoload
-(defun emacspeak-atom-browse (feed)
-  "Browse specified ATOM feed."
-  (interactive
-   (list
-    (let ((completion-ignore-case t))
-      (completing-read "Feed:"
-                       emacspeak-atom-feeds))))
-  (let ((uri (cadr (assoc feed emacspeak-atom-feeds))))
-    (emacspeak-webutils-atom-display uri)))
-
-;;}}}
-
 ;;}}}
 (provide 'emacspeak-webutils)
 ;;{{{ end of file
 
 ;;; local variables:
 ;;; folded-file: t
-;;; byte-compile-dynamic: t
+;;; byte-compile-dynamic: nil
 ;;; end:
 
 ;;}}}
