@@ -1,6 +1,6 @@
 ;;;Auto generated
 
-;;;### (autoloads nil "g-auth" "g-auth.el" (20985 36762 980635 230000))
+;;;### (autoloads nil "g-auth" "g-auth.el" (20980 8332 0 0))
 ;;; Generated autoloads from g-auth.el
 
 (defvar g-auth-lifetime "4 hours" "\
@@ -10,8 +10,7 @@ Auth lifetime.")
 
 ;;;***
 
-;;;### (autoloads nil "gblogger" "gblogger.el" (20762 27152 76955
-;;;;;;  672000))
+;;;### (autoloads nil "gblogger" "gblogger.el" (20980 8308 0 0))
 ;;; Generated autoloads from gblogger.el
 
 (autoload 'gblogger-blog "gblogger" "\
@@ -58,7 +57,7 @@ Resets client so you can start with a different userid.
 
 ;;;***
 
-;;;### (autoloads nil "gbooks" "gbooks.el" (20762 27152 76955 672000))
+;;;### (autoloads nil "gbooks" "gbooks.el" (20980 8308 0 0))
 ;;; Generated autoloads from gbooks.el
 
 (autoload 'gbooks-sign-out "gbooks" "\
@@ -73,7 +72,7 @@ Resets client so you can start with a different userid.
 
 ;;;***
 
-;;;### (autoloads nil "gcal" "gcal.el" (20762 27152 76955 672000))
+;;;### (autoloads nil "gcal" "gcal.el" (20980 8308 0 0))
 ;;; Generated autoloads from gcal.el
 
 (defvar gcal-default-user-email nil "\
@@ -141,8 +140,7 @@ Sign in, useful when changing to a different user profile.
 
 ;;;***
 
-;;;### (autoloads nil "gcontacts" "gcontacts.el" (20762 27152 76955
-;;;;;;  672000))
+;;;### (autoloads nil "gcontacts" "gcontacts.el" (20980 8308 0 0))
 ;;; Generated autoloads from gcontacts.el
 
 (autoload 'gcontacts-initialize "gcontacts" "\
@@ -157,7 +155,7 @@ Create a new contact as specified.
 
 ;;;***
 
-;;;### (autoloads nil "gdocs" "gdocs.el" (20762 27152 76955 672000))
+;;;### (autoloads nil "gdocs" "gdocs.el" (20980 8308 0 0))
 ;;; Generated autoloads from gdocs.el
 
 (autoload 'gdocs-doclist "gdocs" "\
@@ -199,7 +197,7 @@ Resets client so you can start with a different userid.
 
 ;;;***
 
-;;;### (autoloads nil "gfeeds" "gfeeds.el" (20762 27152 76955 672000))
+;;;### (autoloads nil "gfeeds" "gfeeds.el" (21299 32085 0 0))
 ;;; Generated autoloads from gfeeds.el
 
 (defsubst gfeeds-feed (feed-url) "\
@@ -211,7 +209,7 @@ Lookup feed for a given Web page." (declare (special gfeeds-lookup-url gfeeds-re
 (defsubst gfeeds-find (query) "\
 Find feeds matching a query." (declare (special gfeeds-find-url gfeeds-referer)) (let ((result nil)) (g-using-scratch (call-process g-curl-program nil t nil "-s" "-e" gfeeds-referer (format gfeeds-find-url (g-url-encode query))) (goto-char (point-min)) (setq result (json-read)) (when (= 200 (g-json-get (quote responseStatus) result)) (g-json-get (quote entries) (g-json-get (quote responseData) result))))))
 
-(defvar gfeeds-freshness "1 hour" "\
+(defvar gfeeds-freshness "6 hours" "\
 Freshness used to decide if we return titles.")
 
 (custom-autoload 'gfeeds-freshness "gfeeds" nil)
@@ -227,14 +225,9 @@ Interactive prefix arg causes the feed url to be looked up given a Web site.
 
 \(fn URL &optional LOOKUP)" t nil)
 
-(autoload 'gfeeds-lookup-and-view "gfeeds" "\
-Lookup feed URL for a site and browse result.
-
-\(fn SITE)" t nil)
-
 ;;;***
 
-;;;### (autoloads nil "ghealth" "ghealth.el" (20762 27152 76955 672000))
+;;;### (autoloads nil "ghealth" "ghealth.el" (20980 8308 0 0))
 ;;; Generated autoloads from ghealth.el
 
 (autoload 'ghealth-sign-out "ghealth" "\
@@ -249,7 +242,25 @@ Resets client so you can start with a different userid.
 
 ;;;***
 
-;;;### (autoloads nil "gmaps" "gmaps.el" (20882 26303 333899 357000))
+;;;### (autoloads nil "gm-nnir" "gm-nnir.el" (21246 15149 0 0))
+;;; Generated autoloads from gm-nnir.el
+
+(autoload 'gm-nnir-group-make-nnir-group "gm-nnir" "\
+GMail equivalent of gnus-group-make-nnir-group.
+Default is to search All Mail when not on a group.
+
+\(fn)" t nil)
+
+(autoload 'gm-nnir-group-make-gmail-group "gm-nnir" "\
+Use GMail search syntax exclusively.
+See https://support.google.com/mail/answer/7190?hl=en for syntax.
+Default is to search All Mail when not on a Group line.
+
+\(fn)" t nil)
+
+;;;***
+
+;;;### (autoloads nil "gmaps" "gmaps.el" (21339 2666 0 0))
 ;;; Generated autoloads from gmaps.el
 
 (autoload 'gmaps-geocode "gmaps" "\
@@ -279,7 +290,7 @@ Google Maps Interaction.
 
 ;;;***
 
-;;;### (autoloads nil "gphoto" "gphoto.el" (20762 27152 76955 672000))
+;;;### (autoloads nil "gphoto" "gphoto.el" (20980 8308 0 0))
 ;;; Generated autoloads from gphoto.el
 
 (autoload 'gphoto-feeds "gphoto" "\
@@ -367,7 +378,7 @@ The retrieved entry is placed in a buffer ready for editing.
 
 ;;;***
 
-;;;### (autoloads nil "gsheet" "gsheet.el" (20762 27152 76955 672000))
+;;;### (autoloads nil "gsheet" "gsheet.el" (20980 8308 0 0))
 ;;; Generated autoloads from gsheet.el
 
 (autoload 'gsheet-fetch "gsheet" "\
@@ -392,8 +403,7 @@ Resets client so you can start with a different userid.
 
 ;;;***
 
-;;;### (autoloads nil "gskeleton" "gskeleton.el" (20762 27152 76955
-;;;;;;  672000))
+;;;### (autoloads nil "gskeleton" "gskeleton.el" (20980 8308 0 0))
 ;;; Generated autoloads from gskeleton.el
 
 (autoload 'gskeleton-sign-out "gskeleton" "\
@@ -408,7 +418,7 @@ Resets client so you can start with a different userid.
 
 ;;;***
 
-;;;### (autoloads nil "gtube" "gtube.el" (20762 27152 76955 672000))
+;;;### (autoloads nil "gtube" "gtube.el" (20980 8308 0 0))
 ;;; Generated autoloads from gtube.el
 
 (autoload 'gtube-user-profile "gtube" "\
@@ -472,7 +482,7 @@ Retrieved featured video list.
 
 ;;;***
 
-;;;### (autoloads nil "gweb" "gweb.el" (21010 44535 762038 787000))
+;;;### (autoloads nil "gweb" "gweb.el" (21316 41626 0 0))
 ;;; Generated autoloads from gweb.el
 
 (defsubst gweb-google-autocomplete-with-corpus (corpus) "\
@@ -489,12 +499,12 @@ Optional interactive prefix arg refresh forces this cached URL to be refreshed.
 ;;;***
 
 ;;;### (autoloads nil nil ("g-autogen.el" "g-cus-load.el" "g-load-path.el"
-;;;;;;  "g-utils.el" "g.el" "gnotebook.el" "gwis.el" "indent-files.el"
-;;;;;;  "org2blogger.el") (21141 7979 358990 490000))
+;;;;;;  "g-utils.el" "g.el" "gf.el" "gnotebook.el" "gwis.el" "indent-files.el"
+;;;;;;  "org2blogger.el") (21360 56743 700736 612000))
 
 ;;;***
 
-;;;### (autoloads nil "g-app" "g-app.el" (20985 36762 990635 475000))
+;;;### (autoloads nil "g-app" "g-app.el" (20980 8332 0 0))
 ;;; Generated autoloads from g-app.el
 
 (autoload 'g-app-publish "g-app" "\
