@@ -1,5 +1,5 @@
 /*
- * $Id: atcleci.cpp 4731 2007-07-03 14:41:27Z tv.raman.tv $
+ * $Id: atcleci.cpp 9091 2014-04-22 01:35:24Z tv.raman.tv $
  */
 // <copyright info
 
@@ -63,6 +63,7 @@
 
 #include <sys/time.h>
 #include <dlfcn.h>
+#include <alloca.h>
 
 #include <alsa/asoundlib.h>
 #include <tcl.h>
@@ -75,8 +76,8 @@
 // >
 // < alsa: globals and defines
 
-#define DEFAULT_FORMAT          SND_PCM_FORMAT_S16
-#define DEFAULT_SPEED           11025
+#define DEFAULT_FORMAT SND_PCM_FORMAT_S16
+#define DEFAULT_SPEED 11025
 
 /*
  * globals
@@ -84,7 +85,7 @@
 
 static snd_pcm_t *AHandle = NULL;
 static snd_output_t *Log = NULL;
-short          *waveBuffer = NULL;
+short *waveBuffer = NULL;
 
 // >
 // <decls and function prototypes
@@ -97,7 +98,8 @@ short          *waveBuffer = NULL;
  */
 
 typedef enum {
-  eciDataNotProcessed, eciDataProcessed
+  eciDataNotProcessed,
+  eciDataProcessed
 } ECICallbackReturn;
 
 typedef enum {
@@ -121,78 +123,63 @@ typedef enum {
   eciNumParams
 } ECIParam;
 
-static void     (*_eciVersion) (char *);
-static void    *(*_eciNewEx) (enum ECILanguageDialect);
-static int      (*_eciGetAvailableLanguages) (enum
-                                              ECILanguageDialect *, int *);
-static void     (*_eciDelete) (void *);
-static int      (*_eciReset) (void *);
-static int      (*_eciStop) (void *);
-static int      (*_eciClearInput) (void *);
-static int      (*_eciPause) (void *, int);
-static int      (*_eciSynthesize) (void *);
-static int      (*_eciSynchronize) (void *);
-static int      (*_eciSpeaking) (void *);
-static int      (*_eciAddText) (void *, char *);
-static int      (*_eciInsertIndex) (void *, int);
-static int      (*_eciSetParam) (void *, int, int);
-static int      (*_eciGetVoiceParam) (void *, int, int);
-static int      (*_eciSetVoiceParam) (void *, int, int, int);
-static int      (*_eciSetOutputBuffer) (void *, int, short *);
-static int      (*_eciSetOutputDevice) (void *, int);
-static void     (*_eciRegisterCallback) (void *,
-                                         int (*)(void *, int,
-                                                 long, void *), void *);
-static int      alsa_init();
-static void     alsa_reset();   // drop handle and reset
-static size_t   alsa_configure(void);
+static void (*_eciVersion)(char *);
+static void *(*_eciNewEx)(enum ECILanguageDialect);
+static int (*_eciGetAvailableLanguages)(enum ECILanguageDialect *, int *);
+static void (*_eciDelete)(void *);
+static int (*_eciReset)(void *);
+static int (*_eciStop)(void *);
+static int (*_eciClearInput)(void *);
+static int (*_eciPause)(void *, int);
+static int (*_eciSynthesize)(void *);
+static int (*_eciSynchronize)(void *);
+static int (*_eciSpeaking)(void *);
+static int (*_eciAddText)(void *, char *);
+static int (*_eciInsertIndex)(void *, int);
+static int (*_eciSetParam)(void *, int, int);
+static int (*_eciGetVoiceParam)(void *, int, int);
+static int (*_eciSetVoiceParam)(void *, int, int, int);
+static int (*_eciSetOutputBuffer)(void *, int, short *);
+static int (*_eciSetOutputDevice)(void *, int);
+static void (*_eciRegisterCallback)(void *, int(*)(void *, int, long, void *),
+                                    void *);
+static int alsa_init();
+static void alsa_reset(); // drop handle and reset
+static size_t alsa_configure(void);
 
-extern          "C" int Atcleci_Init(Tcl_Interp * interp);
+extern "C" int Atcleci_Init(Tcl_Interp *interp);
 
-int             SetRate(ClientData, Tcl_Interp *, int, Tcl_Obj * CONST[]);
-int             GetRate(ClientData, Tcl_Interp *, int, Tcl_Obj * CONST[]);
-int             getTTSVersion(ClientData, Tcl_Interp *, int,
-                              Tcl_Obj * CONST[]);
-int             showAlsaState(ClientData, Tcl_Interp *, int,
-                              Tcl_Obj * CONST[]);
-int             Say(ClientData, Tcl_Interp *, int, Tcl_Obj * CONST[]);
-int             Stop(ClientData, Tcl_Interp *, int, Tcl_Obj * CONST[]);
-int             SpeakingP(ClientData, Tcl_Interp *, int,
-                          Tcl_Obj * CONST[]);
-int             Synchronize(ClientData, Tcl_Interp *, int,
-                            Tcl_Obj * CONST[]);
-int             Pause(ClientData, Tcl_Interp *, int, Tcl_Obj * CONST[]);
-int             Resume(ClientData, Tcl_Interp *, int, Tcl_Obj * CONST[]);
-int             SetLanguage(ClientData, Tcl_Interp *, int,
-                            Tcl_Obj * CONST[]);
-static int      setOutput(ClientData, Tcl_Interp *, int,
-                          Tcl_Obj * CONST[]);
-int             alsa_close();
-int             eciCallback(void *, int, long, void *);
+int SetRate(ClientData, Tcl_Interp *, int, Tcl_Obj *CONST[]);
+int GetRate(ClientData, Tcl_Interp *, int, Tcl_Obj *CONST[]);
+int getTTSVersion(ClientData, Tcl_Interp *, int, Tcl_Obj *CONST[]);
+int showAlsaState(ClientData, Tcl_Interp *, int, Tcl_Obj *CONST[]);
+int Say(ClientData, Tcl_Interp *, int, Tcl_Obj *CONST[]);
+int Stop(ClientData, Tcl_Interp *, int, Tcl_Obj *CONST[]);
+int SpeakingP(ClientData, Tcl_Interp *, int, Tcl_Obj *CONST[]);
+int Synchronize(ClientData, Tcl_Interp *, int, Tcl_Obj *CONST[]);
+int Pause(ClientData, Tcl_Interp *, int, Tcl_Obj *CONST[]);
+int Resume(ClientData, Tcl_Interp *, int, Tcl_Obj *CONST[]);
+int SetLanguage(ClientData, Tcl_Interp *, int, Tcl_Obj *CONST[]);
+int alsa_close();
+int eciCallback(void *, int, long, void *);
 
 // >
 // <alsa: set hw and sw params
 
-static          size_t
-alsa_configure(void)
-{
+static size_t alsa_configure(void) {
   // <init:
-  size_t          chunk_bytes,
-                  bits_per_sample,
-                  bits_per_frame = 0;
-  snd_pcm_uframes_t chunk_size,
-                  buffer_size = 0;
+  size_t chunk_bytes, bits_per_sample, bits_per_frame = 0;
+  snd_pcm_uframes_t chunk_size, buffer_size = 0;
   snd_pcm_hw_params_t *params;
-  unsigned int    rate = DEFAULT_SPEED;
-  int             err;
+  unsigned int rate = DEFAULT_SPEED;
+  int err;
   snd_pcm_hw_params_alloca(&params);
   // >
   // <defaults:
 
   err = snd_pcm_hw_params_any(AHandle, params);
   if (err < 0) {
-    fprintf(stderr,
-            "PCM: Broken configuration: no configurations available");
+    fprintf(stderr, "PCM: Broken configuration: no configurations available");
     exit(EXIT_FAILURE);
   }
   // >
@@ -227,52 +214,6 @@ alsa_configure(void)
   }
   // >
   // < Set things explicitly if DEBUG
-#ifdef DEBUG
-
-  // <Compute buffer_time:
-  unsigned int    period_time = 0;
-  unsigned int    buffer_time = 0;
-  snd_pcm_uframes_t period_frames = 0;
-  snd_pcm_uframes_t buffer_frames = 0;
-  // affected by defined buffer_size (e.g. via asoundrc)
-  if (buffer_time == 0 && buffer_frames == 0) {
-    err = snd_pcm_hw_params_get_buffer_time(params, &buffer_time, 0);
-    assert(err >= 0);
-    if (buffer_time > 500000)   // usecs
-      buffer_time = 500000;
-  }
-  // >
-  // <Compute period_time:
-
-  if (period_time == 0 && period_frames == 0) {
-    if (buffer_time > 0)
-      period_time = buffer_time / 4;
-    else
-      period_frames = buffer_frames / 4;
-  }
-  if (period_time > 0)
-    err =
-        snd_pcm_hw_params_set_period_time_near(AHandle,
-                                               params, &period_time, 0);
-  else
-    err =
-        snd_pcm_hw_params_set_period_size_near(AHandle,
-                                               params, &period_frames, 0);
-  assert(err >= 0);
-  if (buffer_time > 0) {
-    err =
-        snd_pcm_hw_params_set_buffer_time_near(AHandle,
-                                               params, &buffer_time, 0);
-  } else {
-    err =
-        snd_pcm_hw_params_set_buffer_size_near(AHandle,
-                                               params, &buffer_frames);
-  }
-  assert(err >= 0);
-
-  // >
-#endif
-
   // >
   // <Commit hw params:
   err = snd_pcm_hw_params(AHandle, params);
@@ -286,66 +227,12 @@ alsa_configure(void)
   snd_pcm_hw_params_get_period_size(params, &chunk_size, 0);
   snd_pcm_hw_params_get_buffer_size(params, &buffer_size);
   if (chunk_size == buffer_size) {
-    fprintf(stderr,
-            "Can't use period equal to buffer size (%lu == %lu)",
+    fprintf(stderr, "Can't use period equal to buffer size (%lu == %lu)",
             chunk_size, buffer_size);
     exit(EXIT_FAILURE);
   }
   // >
   // < If DEBUG: SW Params Configure transfer:
-
-#ifdef DEBUG
-  size_t          n;
-  snd_pcm_uframes_t xfer_align;
-  snd_pcm_uframes_t start_threshold,
-                  stop_threshold;
-  int             start_delay = 5;
-  int             stop_delay = 0;
-  snd_pcm_sw_params_t *swParams;
-  snd_pcm_sw_params_alloca(&swParams);
-  snd_pcm_sw_params_current(AHandle, swParams);
-  err = snd_pcm_sw_params_get_xfer_align(swParams, &xfer_align);
-  if (err < 0) {
-    fprintf(stderr, "Unable to obtain xfer align\n");
-    exit(EXIT_FAILURE);
-  }
-  // round up to closest transfer boundary
-  n = (buffer_size / xfer_align) * xfer_align;
-  if (start_delay <= 0) {
-    start_threshold =
-        (snd_pcm_uframes_t) (n + (double) rate * start_delay / 1000000);
-  } else
-    start_threshold =
-        (snd_pcm_uframes_t) ((double) rate * start_delay / 1000000);
-  if (start_threshold < 1)
-    start_threshold = 1;
-  if (start_threshold > n)
-    start_threshold = n;
-  err =
-      snd_pcm_sw_params_set_start_threshold(AHandle, swParams,
-                                            start_threshold);
-  assert(err >= 0);
-  if (stop_delay <= 0)
-    stop_threshold =
-        (snd_pcm_uframes_t) (buffer_size +
-                             (double) rate * stop_delay / 1000000);
-  else
-    stop_threshold =
-        (snd_pcm_uframes_t) ((double) rate * stop_delay / 1000000);
-  err =
-      snd_pcm_sw_params_set_stop_threshold(AHandle, swParams,
-                                           stop_threshold);
-  assert(err >= 0);
-
-  err = snd_pcm_sw_params_set_xfer_align(AHandle, swParams, xfer_align);
-  assert(err >= 0);
-
-  if (snd_pcm_sw_params(AHandle, swParams) < 0) {
-    fprintf(stderr, "unable to install sw params:");
-    exit(EXIT_FAILURE);
-  }
-#endif
-
   // >
   bits_per_sample = snd_pcm_format_physical_width(DEFAULT_FORMAT);
   bits_per_frame = bits_per_sample * 1; // mono
@@ -358,22 +245,20 @@ alsa_configure(void)
 
 #ifndef timersub
 
-#define timersub(a, b, result)                          \
-  do {                                                  \
-    (result)->tv_sec = (a)->tv_sec - (b)->tv_sec;       \
-    (result)->tv_usec = (a)->tv_usec - (b)->tv_usec;    \
-    if ((result)->tv_usec < 0) {                        \
-      --(result)->tv_sec;                               \
-      (result)->tv_usec += 1000000;                     \
-    }                                                   \
+#define timersub(a, b, result)                                                 \
+  do {                                                                         \
+    (result)->tv_sec = (a)->tv_sec - (b)->tv_sec;                              \
+    (result)->tv_usec = (a)->tv_usec - (b)->tv_usec;                           \
+    if ((result)->tv_usec < 0) {                                               \
+      --(result)->tv_sec;                                                      \
+      (result)->tv_usec += 1000000;                                            \
+    }                                                                          \
   } while (0)
 #endif
 
-static void
-xrun(void)
-{
+static void xrun(void) {
   snd_pcm_status_t *status;
-  int             res;
+  int res;
 
   snd_pcm_status_alloca(&status);
   if ((res = snd_pcm_status(AHandle, status)) < 0) {
@@ -381,9 +266,7 @@ xrun(void)
     exit(EXIT_FAILURE);
   }
   if (snd_pcm_status_get_state(status) == SND_PCM_STATE_XRUN) {
-    struct timeval  now,
-                    diff,
-                    tstamp;
+    struct timeval now, diff, tstamp;
     gettimeofday(&now, 0);
     snd_pcm_status_get_trigger_tstamp(status, &tstamp);
     timersub(&now, &tstamp, &diff);
@@ -393,8 +276,8 @@ xrun(void)
       fprintf(stderr, "xrun: prepare error: %s", snd_strerror(res));
       exit(EXIT_FAILURE);
     }
-    return;                     // ok, data should be accepted
-    // again
+    return; // ok, data should be accepted
+            // again
   }
 
   fprintf(stderr, "read/write error, state = %s",
@@ -402,17 +285,14 @@ xrun(void)
   exit(EXIT_FAILURE);
 }
 
-static void
-suspend(void)
-{
-  int             res;
-
+static void suspend(void) {
+  int res;
 
   fprintf(stderr, "Suspended. Trying resume. ");
   fflush(stderr);
   while ((res = snd_pcm_resume(AHandle)) == -EAGAIN)
-    sleep(1);                   /* wait until suspend flag is * * released 
-                                 */
+    sleep(1); /* wait until suspend flag is * * released
+               */
   if (res < 0) {
 
     fprintf(stderr, "Failed. Restarting stream. ");
@@ -429,11 +309,9 @@ suspend(void)
 // >
 // <alsa: pcm_write
 
-static          ssize_t
-pcm_write(short *data, size_t count)
-{
-  ssize_t         r;
-  ssize_t         result = 0;
+static ssize_t pcm_write(short *data, size_t count) {
+  ssize_t r;
+  ssize_t result = 0;
   while (count > 0) {
     r = snd_pcm_writei(AHandle, data, count);
     if (r == -EAGAIN || (r >= 0 && (size_t) r < count)) {
@@ -458,9 +336,7 @@ pcm_write(short *data, size_t count)
 // >
 // <alsa_reset
 
-void
-alsa_reset()
-{
+void alsa_reset() {
   snd_pcm_drop(AHandle);
   snd_pcm_prepare(AHandle);
 }
@@ -468,14 +344,14 @@ alsa_reset()
 // >
 // <alsa_init
 
-int
-alsa_init()
-{
-  int             err;
-  char           *device = "default";
-  size_t          chunk_bytes = 0;
-  if ((err =
-       snd_pcm_open(&AHandle, device, SND_PCM_STREAM_PLAYBACK, 0)) < 0) {
+int alsa_init() {
+  int err;
+  const char *device = getenv("ALSA_DEFAULT");
+  if (device == NULL) {
+    device = "default";
+  }
+  size_t chunk_bytes = 0;
+  if ((err = snd_pcm_open(&AHandle, device, SND_PCM_STREAM_PLAYBACK, 0)) < 0) {
     fprintf(stderr, "Playback open error: %s\n", snd_strerror(err));
     exit(1);
   }
@@ -488,9 +364,7 @@ alsa_init()
 // >
 // <alsa_close
 
-int
-alsa_close()
-{
+int alsa_close() {
   // shut down alsa
   snd_pcm_close(AHandle);
   free(waveBuffer);
@@ -500,82 +374,64 @@ alsa_close()
 // >
 // <eciFree
 
-void
-TclEciFree(ClientData eciHandle)
-{
-  _eciDelete(eciHandle);
-}
+void TclEciFree(ClientData eciHandle) { _eciDelete(eciHandle); }
 
 // >
 // <tcleci_init
 
-int
-Atcleci_Init(Tcl_Interp * interp)
-{
-  int             rc;
-  size_t          chunk_bytes = 0;
-  void           *eciHandle;
-  void           *eciLib;
+int Atcleci_Init(Tcl_Interp *interp) {
+  int rc;
+  size_t chunk_bytes = 0;
+  void *eciHandle;
+  void *eciLib;
   // < configure shared library symbols
 
   eciLib = dlopen(ECILIBRARYNAME, RTLD_LAZY);
   if (eciLib == NULL) {
-    Tcl_AppendResult(interp, "Could not load ",
-                     ECILIBRARYNAME,
-                     "\nPlease install the IBM ViaVoice Outloud RTK",
-                     NULL);
+    Tcl_AppendResult(interp, "Could not load ", ECILIBRARYNAME, "\n", dlerror(),
+                     "\nPlease install the IBM ViaVoice Outloud RTK", NULL);
     return TCL_ERROR;
   }
 
-  _eciVersion =
-      (void (*)(char *)) (unsigned long) dlsym(eciLib, "eciVersion");
+  _eciVersion = (void(*)(char *))(unsigned long) dlsym(eciLib, "eciVersion");
   _eciGetAvailableLanguages =
-      (int (*)(enum ECILanguageDialect *, int *)) (unsigned long)
+      (int(*)(enum ECILanguageDialect *, int *))(unsigned long)
       dlsym(eciLib, "eciGetAvailableLanguages");
-  _eciNewEx = (void *(*)(enum ECILanguageDialect)) (unsigned long)
+  _eciNewEx = (void * (*)(enum ECILanguageDialect))(unsigned long)
       dlsym(eciLib, "eciNewEx");
-  _eciDelete =
-      (void (*)(void *)) (unsigned long) dlsym(eciLib, "eciDelete");
-  _eciReset = (int (*)(void *)) (unsigned long) dlsym(eciLib, "eciReset");
-  _eciStop = (int (*)(void *)) (unsigned long) dlsym(eciLib, "eciStop");
+  _eciDelete = (void(*)(void *))(unsigned long) dlsym(eciLib, "eciDelete");
+  _eciReset = (int(*)(void *))(unsigned long) dlsym(eciLib, "eciReset");
+  _eciStop = (int(*)(void *))(unsigned long) dlsym(eciLib, "eciStop");
   _eciClearInput =
-      (int (*)(void *)) (unsigned long) dlsym(eciLib, "eciClearInput");
-  _eciPause =
-      (int (*)(void *, int)) (unsigned long) dlsym(eciLib, "eciPause");
+      (int(*)(void *))(unsigned long) dlsym(eciLib, "eciClearInput");
+  _eciPause = (int(*)(void *, int))(unsigned long) dlsym(eciLib, "eciPause");
   _eciSynthesize =
-      (int (*)(void *)) (unsigned long) dlsym(eciLib, "eciSynthesize");
+      (int(*)(void *))(unsigned long) dlsym(eciLib, "eciSynthesize");
   _eciSynchronize =
-      (int (*)(void *)) (unsigned long) dlsym(eciLib, "eciSynchronize");
-  _eciSpeaking =
-      (int (*)(void *)) (unsigned long) dlsym(eciLib, "eciSpeaking");
+      (int(*)(void *))(unsigned long) dlsym(eciLib, "eciSynchronize");
+  _eciSpeaking = (int(*)(void *))(unsigned long) dlsym(eciLib, "eciSpeaking");
   _eciInsertIndex =
-      (int (*)(void *, int)) (unsigned long) dlsym(eciLib,
-                                                   "eciInsertIndex");
+      (int(*)(void *, int))(unsigned long) dlsym(eciLib, "eciInsertIndex");
   _eciAddText =
-      (int (*)(void *, char *)) (unsigned long) dlsym(eciLib,
-                                                      "eciAddText");
+      (int(*)(void *, char *))(unsigned long) dlsym(eciLib, "eciAddText");
   _eciSetParam =
-      (int (*)(void *, int, int)) (unsigned long) dlsym(eciLib,
-                                                        "eciSetParam");
-  _eciGetVoiceParam = (int (*)(void *, int, int))
-      (unsigned long) dlsym(eciLib, "eciGetVoiceParam");
-  _eciSetVoiceParam = (int (*)(void *, int, int, int))
-      (unsigned long) dlsym(eciLib, "eciSetVoiceParam");
-  _eciRegisterCallback = (void
-                          (*)(void *,
-                              int (*)(void *, int, long,
-                                      void *), void *)) (unsigned long)
-      dlsym(eciLib, "eciRegisterCallback");
-  _eciSetOutputBuffer = (int (*)(void *, int, short *)) (unsigned long)
+      (int(*)(void *, int, int))(unsigned long) dlsym(eciLib, "eciSetParam");
+  _eciGetVoiceParam = (int(*)(void *, int, int))(unsigned long)
+      dlsym(eciLib, "eciGetVoiceParam");
+  _eciSetVoiceParam = (int(*)(void *, int, int, int))(unsigned long)
+      dlsym(eciLib, "eciSetVoiceParam");
+  _eciRegisterCallback =
+      (void(*)(void *, int(*)(void *, int, long, void *), void *))(
+          unsigned long) dlsym(eciLib, "eciRegisterCallback");
+  _eciSetOutputBuffer = (int(*)(void *, int, short *))(unsigned long)
       dlsym(eciLib, "eciSetOutputBuffer");
   _eciSetOutputDevice =
-      (int (*)(void *, int)) (unsigned long) dlsym(eciLib,
-                                                   "eciSetOutputDevice");
+      (int(*)(void *, int))(unsigned long) dlsym(eciLib, "eciSetOutputDevice");
 
   // >
   // < check for needed symbols
 
-  int             okay = 1;
+  int okay = 1;
   if (!_eciNewEx) {
     okay = 0;
     Tcl_AppendResult(interp, "eciNewEx undef\n", NULL);
@@ -649,8 +505,7 @@ Atcleci_Init(Tcl_Interp * interp)
     Tcl_AppendResult(interp, "_eciGetAvailableLanguages undef\n", NULL);
   }
   if (!okay) {
-    Tcl_AppendResult(interp, "Missing symbols from ",
-                     ECILIBRARYNAME, NULL);
+    Tcl_AppendResult(interp, "Missing symbols from ", ECILIBRARYNAME, NULL);
     return TCL_ERROR;
   }
   // >
@@ -662,7 +517,7 @@ Atcleci_Init(Tcl_Interp * interp)
   }
 
   static enum ECILanguageDialect aLanguages[LANG_INFO_MAX];
-  int             nLanguages = LANG_INFO_MAX;
+  int nLanguages = LANG_INFO_MAX;
   _eciGetAvailableLanguages(aLanguages, &nLanguages);
 
   enum ECILanguageDialect aDefaultLanguage =
@@ -671,7 +526,7 @@ Atcleci_Init(Tcl_Interp * interp)
     Tcl_AppendResult(interp, "No language found", PACKAGENAME, NULL);
     return TCL_ERROR;
   }
-
+  fprintf(stderr, "Found %d languages.\n", nLanguages);
   eciHandle = _eciNewEx(aDefaultLanguage);
   if (eciHandle == 0) {
     Tcl_AppendResult(interp, "Could not open text-to-speech engine", NULL);
@@ -682,19 +537,20 @@ Atcleci_Init(Tcl_Interp * interp)
   chunk_bytes = alsa_init();
   // <Finally, allocate waveBuffer
 
-  fprintf(stderr, "allocating %d samples\n", chunk_bytes);
-  waveBuffer = (short *) malloc(chunk_bytes * sizeof(short));
+  fprintf(stderr, "allocating %d samples\n", (int) chunk_bytes);
+  waveBuffer = (short *)malloc(chunk_bytes * sizeof(short));
   if (waveBuffer == NULL) {
     fprintf(stderr, "not enough memory");
+    alsa_close();
     exit(EXIT_FAILURE);
   }
   // >
   // >
   // <initialize TTS
 
-  if ((_eciSetParam(eciHandle, eciInputType, 1) == -1)
-      || (_eciSetParam(eciHandle, eciSynthMode, 1) == -1)
-      || (_eciSetParam(eciHandle, eciSampleRate, 1) == -1)) {
+  if ((_eciSetParam(eciHandle, eciInputType, 1) == -1) ||
+      (_eciSetParam(eciHandle, eciSynthMode, 1) == -1) ||
+      (_eciSetParam(eciHandle, eciSampleRate, 1) == -1)) {
     Tcl_AppendResult(interp, "Could not initialized tts", NULL);
     _eciDelete(eciHandle);
     return TCL_ERROR;
@@ -714,35 +570,32 @@ Atcleci_Init(Tcl_Interp * interp)
     Tcl_AppendResult(interp, "Error setting output buffer.\n", NULL);
     return TCL_ERROR;
   }
-  fprintf(stderr,
-          "output buffered to waveBuffer with size %d\n", chunk_bytes);
+  fprintf(stderr, "output buffered to waveBuffer with size %d\n",
+          (int) chunk_bytes);
 
   // >
   // <register tcl commands
 
-  Tcl_CreateObjCommand(interp, "setRate", SetRate,
-                       (ClientData) eciHandle, TclEciFree);
-  Tcl_CreateObjCommand(interp, "getRate", GetRate,
-                       (ClientData) eciHandle, TclEciFree);
+  Tcl_CreateObjCommand(interp, "setRate", SetRate, (ClientData) eciHandle,
+                       TclEciFree);
+  Tcl_CreateObjCommand(interp, "getRate", GetRate, (ClientData) eciHandle,
+                       TclEciFree);
   Tcl_CreateObjCommand(interp, "ttsVersion", getTTSVersion,
                        (ClientData) eciHandle, TclEciFree);
-  Tcl_CreateObjCommand(interp, "alsaState", showAlsaState,
-                       (ClientData) NULL, TclEciFree);
-  Tcl_CreateObjCommand(interp, "say", Say,
-                       (ClientData) eciHandle, TclEciFree);
+  Tcl_CreateObjCommand(interp, "alsaState", showAlsaState, (ClientData) NULL,
+                       TclEciFree);
+  Tcl_CreateObjCommand(interp, "say", Say, (ClientData) eciHandle, TclEciFree);
   Tcl_CreateObjCommand(interp, "synth", Say, (ClientData) eciHandle, NULL);
   Tcl_CreateObjCommand(interp, "synchronize", Synchronize,
                        (ClientData) eciHandle, TclEciFree);
-  Tcl_CreateObjCommand(interp, "stop", Stop,
-                       (ClientData) eciHandle, TclEciFree);
-  Tcl_CreateObjCommand(interp, "speakingP", SpeakingP,
-                       (ClientData) eciHandle, TclEciFree);
-  Tcl_CreateObjCommand(interp, "pause", Pause,
-                       (ClientData) eciHandle, TclEciFree);
-  Tcl_CreateObjCommand(interp, "resume", Resume,
-                       (ClientData) eciHandle, TclEciFree);
-  Tcl_CreateObjCommand(interp, "setOutput", setOutput,
-                       (ClientData) eciHandle, TclEciFree);
+  Tcl_CreateObjCommand(interp, "stop", Stop, (ClientData) eciHandle,
+                       TclEciFree);
+  Tcl_CreateObjCommand(interp, "speakingP", SpeakingP, (ClientData) eciHandle,
+                       TclEciFree);
+  Tcl_CreateObjCommand(interp, "pause", Pause, (ClientData) eciHandle,
+                       TclEciFree);
+  Tcl_CreateObjCommand(interp, "resume", Resume, (ClientData) eciHandle,
+                       TclEciFree);
   Tcl_CreateObjCommand(interp, "setLanguage", SetLanguage,
                        (ClientData) eciHandle, TclEciFree);
   // >
@@ -758,9 +611,7 @@ set tts(last_index) $x}");
 // >
 // <playTTS
 
-int
-playTTS(int count)
-{
+int playTTS(int count) {
   pcm_write(waveBuffer, count);
   return eciDataProcessed;
 }
@@ -768,15 +619,12 @@ playTTS(int count)
 // >
 // <eciCallBack
 
-int
-eciCallback(void *eciHandle, int msg, long lparam, void *data)
-{
-  int             rc;
-  Tcl_Interp     *interp = (Tcl_Interp *) data;
+int eciCallback(void *eciHandle, int msg, long lparam, void *data) {
+  Tcl_Interp *interp = (Tcl_Interp *)data;
   if (msg == eciIndexReply) {
-    char            buffer[128];
+    char buffer[128];
     snprintf(buffer, 128, "index %ld", lparam);
-    rc = Tcl_Eval(interp, buffer);
+    int rc = Tcl_Eval(interp, buffer);
     if (rc != TCL_OK)
       Tcl_BackgroundError(interp);
   } else if ((msg == eciWaveformBuffer) && (lparam > 0)) {
@@ -788,13 +636,9 @@ eciCallback(void *eciHandle, int msg, long lparam, void *data)
 // >
 // <getRate, setRate
 
-int
-GetRate(ClientData eciHandle, Tcl_Interp * interp,
-        int objc, Tcl_Obj * CONST objv[])
-{
-  int             rc,
-                  rate,
-                  voice;
+int GetRate(ClientData eciHandle, Tcl_Interp *interp, int objc,
+            Tcl_Obj *CONST objv[]) {
+  int rc, rate, voice;
   if (objc != 2) {
     Tcl_AppendResult(interp, "Usage: getRate voiceCode  ", TCL_STATIC);
     return TCL_ERROR;
@@ -802,21 +646,17 @@ GetRate(ClientData eciHandle, Tcl_Interp * interp,
   rc = Tcl_GetIntFromObj(interp, objv[1], &voice);
   if (rc != TCL_OK)
     return rc;
-  rate = _eciGetVoiceParam(eciHandle, voice, 6 /* eciSpeed */ );
+  rate = _eciGetVoiceParam(eciHandle, voice, 6 /* eciSpeed */);
   Tcl_SetObjResult(interp, Tcl_NewIntObj(rate));
   return TCL_OK;
 }
 
-int
-SetRate(ClientData eciHandle, Tcl_Interp * interp,
-        int objc, Tcl_Obj * CONST objv[])
-{
-  int             rc,
-                  rate,
-                  voice;
+int SetRate(ClientData eciHandle, Tcl_Interp *interp, int objc,
+            Tcl_Obj *CONST objv[]) {
+  int rc, rate, voice;
   if (objc != 3) {
-    Tcl_AppendResult(interp,
-                     "Usage: setRate voiceCode speechRate ", TCL_STATIC);
+    Tcl_AppendResult(interp, "Usage: setRate voiceCode speechRate ",
+                     TCL_STATIC);
     return TCL_ERROR;
   }
   rc = Tcl_GetIntFromObj(interp, objv[1], &voice);
@@ -825,38 +665,31 @@ SetRate(ClientData eciHandle, Tcl_Interp * interp,
   rc = Tcl_GetIntFromObj(interp, objv[2], &rate);
   if (rc != TCL_OK)
     return rc;
-  rc = _eciSetVoiceParam(eciHandle, voice, 6 /* eciSpeed */ ,
-                         rate);
+  rc = _eciSetVoiceParam(eciHandle, voice, 6 /* eciSpeed */, rate);
   if (rc == -1) {
     Tcl_AppendResult(interp, "Could not set rate", TCL_STATIC);
     return TCL_ERROR;
   }
   // fprintf(stderr, "setRate returned %d\n", rc);
-  rate = _eciGetVoiceParam(eciHandle, voice, 6 /* eciSpeed */ );
-  fprintf(stderr,
-          "eciGetVoiceParam returned %d for voice %d \n", rate, voice);
+  rate = _eciGetVoiceParam(eciHandle, voice, 6 /* eciSpeed */);
+  fprintf(stderr, "eciGetVoiceParam returned %d for voice %d \n", rate, voice);
   return TCL_OK;
 }
 
 // >
 // <say
 
-int
-Say(ClientData eciHandle, Tcl_Interp * interp,
-    int objc, Tcl_Obj * CONST objv[])
-{
-  int             i,
-                  rc,
-                  index,
-                  length;
+int Say(ClientData eciHandle, Tcl_Interp *interp, int objc,
+        Tcl_Obj *CONST objv[]) {
+  int i, rc, index, length;
   for (i = 1; i < objc; i++) {
     // if string begins with -, assume it is an index value
-    char           *txt = Tcl_GetStringFromObj(objv[i], &length);
+    char *txt = Tcl_GetStringFromObj(objv[i], &length);
     if (Tcl_StringMatch(txt, "-reset")) {
       _eciReset(eciHandle);
-      if ((_eciSetParam(eciHandle, eciInputType, 1) == -1)
-          || (_eciSetParam(eciHandle, eciSynthMode, 1) == -1)
-          || (_eciSetParam(eciHandle, eciSampleRate, 1) == -1)) {
+      if ((_eciSetParam(eciHandle, eciInputType, 1) == -1) ||
+          (_eciSetParam(eciHandle, eciSynthMode, 1) == -1) ||
+          (_eciSetParam(eciHandle, eciSampleRate, 1) == -1)) {
         Tcl_AppendResult(interp, "Could not re-initialized tts", NULL);
         return TCL_ERROR;
       }
@@ -875,14 +708,13 @@ Say(ClientData eciHandle, Tcl_Interp * interp,
         return TCL_ERROR;
       }
     } else {
-      char           *dest = convertFromUTF8(interp,
-                                             Tcl_GetStringFromObj(objv[i],
-                                                                  NULL));
+      char *dest = convertFromUTF8(interp, Tcl_GetStringFromObj(objv[i], NULL));
       if (dest) {
         rc = _eciAddText(eciHandle, dest);
         free(dest);
         if (!rc) {
-          Tcl_SetResult(interp, "Internal tts error", TCL_STATIC);
+          Tcl_SetResult(interp, const_cast<char *>("Internal tts error"),
+                        TCL_STATIC);
           return TCL_ERROR;
         }
       }
@@ -891,7 +723,8 @@ Say(ClientData eciHandle, Tcl_Interp * interp,
   if (Tcl_StringMatch(Tcl_GetStringFromObj(objv[0], NULL), "synth")) {
     rc = _eciSynthesize(eciHandle);
     if (!rc) {
-      Tcl_SetResult(interp, "Internal tts synth error", TCL_STATIC);
+      Tcl_SetResult(interp, const_cast<char *>("Internal tts synth error"),
+                    TCL_STATIC);
       return TCL_ERROR;
     }
   }
@@ -903,37 +736,33 @@ Say(ClientData eciHandle, Tcl_Interp * interp,
 
 // <synchronize, stop
 
-int
-Synchronize(ClientData eciHandle,
-            Tcl_Interp * interp, int objc, Tcl_Obj * CONST objv[])
-{
-  int             rc = _eciSynchronize(eciHandle);
+int Synchronize(ClientData eciHandle, Tcl_Interp *interp, int objc,
+                Tcl_Obj *CONST objv[]) {
+  int rc = _eciSynchronize(eciHandle);
   if (!rc) {
-    Tcl_SetResult(interp, "Internal tts synth error", TCL_STATIC);
+    Tcl_SetResult(interp, const_cast<char *>("Internal tts synth error"),
+                  TCL_STATIC);
     return TCL_ERROR;
   }
   return TCL_OK;
 }
 
-int
-Stop(ClientData eciHandle,
-     Tcl_Interp * interp, int objc, Tcl_Obj * CONST objv[])
-{
+int Stop(ClientData eciHandle, Tcl_Interp *interp, int objc,
+         Tcl_Obj *CONST objv[]) {
   if (_eciStop(eciHandle)) {
     alsa_reset();
     usleep(10);
     return TCL_OK;
   }
-  Tcl_SetResult(interp, "Could not stop synthesis", TCL_STATIC);
+  Tcl_SetResult(interp, const_cast<char *>("Could not stop synthesis"),
+                TCL_STATIC);
   return TCL_ERROR;
 }
 
 // >
 
-int
-SpeakingP(ClientData eciHandle, Tcl_Interp * interp, int objc,
-          Tcl_Obj * CONST objv[])
-{
+int SpeakingP(ClientData eciHandle, Tcl_Interp *interp, int objc,
+              Tcl_Obj *CONST objv[]) {
   if (_eciSpeaking(eciHandle)) {
     Tcl_SetObjResult(interp, Tcl_NewIntObj(1));
   } else {
@@ -942,49 +771,34 @@ SpeakingP(ClientData eciHandle, Tcl_Interp * interp, int objc,
   return TCL_OK;
 }
 
-int
-Pause(ClientData eciHandle, Tcl_Interp * interp, int objc,
-      Tcl_Obj * CONST objv[])
-{
+int Pause(ClientData eciHandle, Tcl_Interp *interp, int objc,
+          Tcl_Obj *CONST objv[]) {
   if (_eciPause(eciHandle, 1))
     return TCL_OK;
-  Tcl_SetResult(interp, "Could not pause synthesis", TCL_STATIC);
+  Tcl_SetResult(interp, const_cast<char *>("Could not pause synthesis"),
+                TCL_STATIC);
   return TCL_ERROR;
 }
 
-int
-Resume(ClientData eciHandle, Tcl_Interp * interp, int objc,
-       Tcl_Obj * CONST objv[])
-{
+int Resume(ClientData eciHandle, Tcl_Interp *interp, int objc,
+           Tcl_Obj *CONST objv[]) {
   if (_eciPause(eciHandle, 0))
     return TCL_OK;
-  Tcl_SetResult(interp, "Could not resume synthesis", TCL_STATIC);
+  Tcl_SetResult(interp, const_cast<char *>("Could not resume synthesis"),
+                TCL_STATIC);
   return TCL_ERROR;
 }
 
-// >
-// <setOutput:NoOp
-
-int
-setOutput(ClientData eciHandle, Tcl_Interp * interp, int objc,
-          Tcl_Obj * CONST objv[])
-{
-  Tcl_AppendResult(interp, "setOuputput: No-Op under Alsa\n", TCL_STATIC);
-  return TCL_OK;
-}
-
 // >
 // <getVersion
 
-int
-getTTSVersion(ClientData eciHandle, Tcl_Interp * interp,
-              int objc, Tcl_Obj * CONST objv[])
-{
-  char           *version = (char *) malloc(16);
+int getTTSVersion(ClientData eciHandle, Tcl_Interp *interp, int objc,
+                  Tcl_Obj *CONST objv[]) {
   if (objc != 1) {
     Tcl_AppendResult(interp, "Usage: ttsVersion   ", TCL_STATIC);
     return TCL_ERROR;
   }
+  char *version = (char *)alloca(16);
   _eciVersion(version);
   Tcl_SetResult(interp, version, TCL_STATIC);
   return TCL_OK;
@@ -993,10 +807,8 @@ getTTSVersion(ClientData eciHandle, Tcl_Interp * interp,
 // >
 // <show alsa state
 
-int
-showAlsaState(ClientData eciHandle, Tcl_Interp * interp,
-              int objc, Tcl_Obj * CONST objv[])
-{
+int showAlsaState(ClientData eciHandle, Tcl_Interp *interp, int objc,
+                  Tcl_Obj *CONST objv[]) {
   if (objc != 1) {
     Tcl_AppendResult(interp, "Usage: alsaState   ", TCL_STATIC);
     return TCL_ERROR;
@@ -1008,15 +820,13 @@ showAlsaState(ClientData eciHandle, Tcl_Interp * interp,
 // >
 // <SetLanguage
 
-int
-SetLanguage(ClientData eciHandle, Tcl_Interp * interp,
-            int objc, Tcl_Obj * CONST objv[])
-{
-  int             aIndex;
-  const char     *code = getAnnotation(interp, &aIndex);
+int SetLanguage(ClientData eciHandle, Tcl_Interp *interp, int objc,
+                Tcl_Obj *CONST objv[]) {
+  int aIndex;
+  const char *code = getAnnotation(interp, &aIndex);
   if (code) {
-    int             rc;
-    char            buffer[ANNOTATION_MAX_SIZE];
+    int rc;
+    char buffer[ANNOTATION_MAX_SIZE];
     snprintf(buffer, ANNOTATION_MAX_SIZE, "`l%s", code);
     rc = _eciAddText(eciHandle, buffer);
   }
